<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:msa="http://www.publictalksoftware.co.uk/msa" xmlns="http://www.w3.org/1999/xhtml">
  <xsl:output method="html" indent="yes" version="4.01"
    doctype-system="http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"
    doctype-public="-//W3C//DTD XHTML 1.0 Transitional//EN"/>

  <xsl:variable name="DutyHistory" select="document('DutyAssignHistory.XML')"/>
  <xsl:variable name="Translations" select="document('Workbook-S-140-Compact_2021_v1_Translations.XML')"/>

  <!-- Set the language code (we need to take into account the Foreign Language Group mode) -->
  <xsl:variable name="LangCode">
    <xsl:choose>
      <xsl:when test="//Settings/ForeignGroupMode='1'">
        <xsl:value-of select="//Settings/ForeignGroupLanguageCode"/>
      </xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="//Settings/LanguageCode"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:variable>

  <!-- Set the language direction (we need to take into account the Foreign Language Group mode) -->
  <xsl:variable name="LangDirection">
    <xsl:choose>
      <xsl:when test="//Settings/ForeignGroupMode='1'">
        <xsl:value-of select="//Settings/ForeignGroupDirection"/>
      </xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="//Settings/Direction"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:variable>

  <xsl:template match="/">
    <html xmlns="http://www.w3.org/1999/xhtml">
      <xsl:attribute name="lang">
        <xsl:value-of select="$LangCode"/>
      </xsl:attribute>
      <xsl:attribute name="dir">
        <xsl:value-of select="$LangDirection"/>
      </xsl:attribute>
      <head>
        <meta http-equiv="X-UA-Compatible" content="IE=edge" />
        <meta content="text/html; charset=utf-8" http-equiv="Content-Type" />
        <link rel="stylesheet" type="text/css" href="Workbook-S-140-Compact.css"/>
        <title>
          <xsl:value-of select="//Labels/Congregation"/>&#160;<xsl:value-of select="//Labels/Title" />
        </title>
      </head>
      <body>
        <div class="containerPage">
          <table cellpadding="0" cellspacing="0" class="tableSchedule">
            <xsl:call-template name="SetColumnWidths"/>

            <!--Insert row of Meeting / Special Event Dates-->
            <tr>
              <xsl:call-template name="EmptyLabelCell"/>

              <!-- Only display the Special Event information if:
                     1. It is an "All Day Event" (no meetings).
                     2. It is a "Midweek Memorial Event" (no midweek meeting) -->
              <!-- MeetingDate elements are only present in the data file if there is an actual "Midweek Meeting" for the week -->
              <xsl:apply-templates select="MeetingWorkBook/Meeting[1]/SpecialEvent/Date[@AllDayEvent='1' or (@MidweekEvent='1' and @Memorial='1')]"/>
              <xsl:apply-templates select="MeetingWorkBook/Meeting[1]/MeetingDate"/>
              <xsl:apply-templates select="MeetingWorkBook/Meeting[2]/SpecialEvent/Date[@AllDayEvent='1' or (@MidweekEvent='1' and @Memorial='1')]"/>
              <xsl:apply-templates select="MeetingWorkBook/Meeting[2]/MeetingDate"/>
              <xsl:apply-templates select="MeetingWorkBook/Meeting[3]/SpecialEvent/Date[@AllDayEvent='1' or (@MidweekEvent='1' and @Memorial='1')]"/>
              <xsl:apply-templates select="MeetingWorkBook/Meeting[3]/MeetingDate"/>
              <xsl:apply-templates select="MeetingWorkBook/Meeting[4]/SpecialEvent/Date[@AllDayEvent='1' or (@MidweekEvent='1' and @Memorial='1')]"/>
              <xsl:apply-templates select="MeetingWorkBook/Meeting[4]/MeetingDate"/>
              <xsl:apply-templates select="MeetingWorkBook/Meeting[5]/SpecialEvent/Date[@AllDayEvent='1' or (@MidweekEvent='1' and @Memorial='1')]"/>
              <xsl:apply-templates select="MeetingWorkBook/Meeting[5]/MeetingDate"/>
            </tr>

            <!-- Display the main schedule heading -->
            <xsl:call-template name="Heading">
              <xsl:with-param name="strTitle">
                <xsl:value-of select="$Translations/msa:Translations/msa:*[local-name() = $LangCode]/msa:ScheduleHeading"/>
              </xsl:with-param>
              <xsl:with-param name="strClass">cellHEADING</xsl:with-param>
            </xsl:call-template>

            <!-- Insert row of assigned Chairman (or the Special Event description) -->
            <tr>
              <td class="cellLabel">
                <xsl:value-of select="$Translations/msa:Translations/msa:*[local-name() = $LangCode]/msa:Chairman"/>
              </td>
              <!-- Only display the Special Event information if:
                     1. It is an "All day Event" (no meetings)
                     2. It is a "Midweek Memorial Event" (no midweek meeting) -->
              <xsl:apply-templates select="MeetingWorkBook/Meeting[1]/SpecialEvent[Date/@AllDayEvent='1' or (Date/@MidweekEvent='1' and Date/@Memorial='1')]/Event" mode="FirstRow_Pray">
                <xsl:with-param name="strClass">cellBold borderRight</xsl:with-param>
              </xsl:apply-templates>
              <xsl:apply-templates select="MeetingWorkBook/Meeting[1]/Chairman" mode="FirstRow_Pray">
                <xsl:with-param name="strClass">cellBold borderRightBottom</xsl:with-param>
              </xsl:apply-templates>
              <xsl:apply-templates select="MeetingWorkBook/Meeting[2]/SpecialEvent[Date/@AllDayEvent='1' or (Date/@MidweekEvent='1' and Date/@Memorial='1')]/Event" mode="FirstRow_Pray">
                <xsl:with-param name="strClass">cellBold borderLeftRight</xsl:with-param>
              </xsl:apply-templates>
              <xsl:apply-templates select="MeetingWorkBook/Meeting[2]/Chairman" mode="FirstRow_Pray">
                <xsl:with-param name="strClass">cellBold borderLeftRightBottom</xsl:with-param>
              </xsl:apply-templates>
              <xsl:apply-templates select="MeetingWorkBook/Meeting[3]/SpecialEvent[Date/@AllDayEvent='1' or (Date/@MidweekEvent='1' and Date/@Memorial='1')]/Event" mode="FirstRow_Pray">
                <xsl:with-param name="strClass">cellBold borderLeftRight</xsl:with-param>
              </xsl:apply-templates>
              <xsl:apply-templates select="MeetingWorkBook/Meeting[3]/Chairman" mode="FirstRow_Pray">
                <xsl:with-param name="strClass">cellBold borderLeftRightBottom</xsl:with-param>
              </xsl:apply-templates>
              <xsl:choose>
                <xsl:when test="count(MeetingWorkBook/Meeting) = 4">
                  <xsl:apply-templates select="MeetingWorkBook/Meeting[4]/SpecialEvent[Date/@AllDayEvent='1' or (Date/@MidweekEvent='1' and Date/@Memorial='1')]/Event" mode="FirstRow_Pray">
                    <xsl:with-param name="strClass">cellBold borderLeft</xsl:with-param>
                  </xsl:apply-templates>
                  <xsl:apply-templates select="MeetingWorkBook/Meeting[4]/Chairman" mode="FirstRow_Pray">
                    <xsl:with-param name="strClass">cellBold borderLeftBottom</xsl:with-param>
                  </xsl:apply-templates>
                </xsl:when>
                <xsl:otherwise>
                  <xsl:apply-templates select="MeetingWorkBook/Meeting[4]/SpecialEvent[Date/@AllDayEvent='1' or (Date/@MidweekEvent='1' and Date/@Memorial='1')]/Event" mode="FirstRow_Pray">
                    <xsl:with-param name="strClass">cellBold borderLeftRight</xsl:with-param>
                  </xsl:apply-templates>
                  <xsl:apply-templates select="MeetingWorkBook/Meeting[4]/Chairman" mode="FirstRow_Pray">
                    <xsl:with-param name="strClass">cellBold borderLeftRightBottom</xsl:with-param>
                  </xsl:apply-templates>
                  <xsl:apply-templates select="MeetingWorkBook/Meeting[5]/SpecialEvent[Date/@AllDayEvent='1' or (Date/@MidweekEvent='1' and Date/@Memorial='1')]/Event" mode="FirstRow_Pray">
                    <xsl:with-param name="strClass">cellBold borderLeft</xsl:with-param>
                  </xsl:apply-templates>
                  <xsl:apply-templates select="MeetingWorkBook/Meeting[5]/Chairman" mode="FirstRow_Pray">
                    <xsl:with-param name="strClass">cellBold borderLeftBottom</xsl:with-param>
                  </xsl:apply-templates>
                </xsl:otherwise>
              </xsl:choose>
            </tr>

            <!-- Insert row of assigned Prayer (or the Special Event description) -->
            <tr>
              <td class="cellLabel">
                <xsl:value-of select="$Translations/msa:Translations/msa:*[local-name() = $LangCode]/msa:Prayer"/>
              </td>
              <xsl:apply-templates select="MeetingWorkBook/Meeting[1]/PrayerOpen" mode="OtherRow">
                <xsl:with-param name="strClass">borderRight</xsl:with-param>
              </xsl:apply-templates>
              <xsl:apply-templates select="MeetingWorkBook/Meeting[2]/PrayerOpen" mode="OtherRow">
                <xsl:with-param name="strClass">borderLeftRight</xsl:with-param>
              </xsl:apply-templates>
              <xsl:apply-templates select="MeetingWorkBook/Meeting[3]/PrayerOpen" mode="OtherRow">
                <xsl:with-param name="strClass">borderLeftRight</xsl:with-param>
              </xsl:apply-templates>
              <xsl:choose>
                <xsl:when test="count(MeetingWorkBook/Meeting) = 4">
                  <xsl:apply-templates select="MeetingWorkBook/Meeting[4]/PrayerOpen" mode="OtherRow">
                    <xsl:with-param name="strClass">borderLeft</xsl:with-param>
                  </xsl:apply-templates>
                </xsl:when>
                <xsl:otherwise>
                  <xsl:apply-templates select="MeetingWorkBook/Meeting[4]/PrayerOpen" mode="OtherRow">
                    <xsl:with-param name="strClass">borderLeftRight</xsl:with-param>
                  </xsl:apply-templates>
                  <xsl:apply-templates select="MeetingWorkBook/Meeting[5]/PrayerOpen" mode="OtherRow">
                    <xsl:with-param name="strClass">borderLeft</xsl:with-param>
                  </xsl:apply-templates>
                </xsl:otherwise>
              </xsl:choose>
            </tr>

            <!-- Display TFGW Heading -->
            <xsl:call-template name="Heading">
              <xsl:with-param name="strTitle">
                <xsl:value-of select="$Translations/msa:Translations/msa:*[local-name() = $LangCode]/msa:SectionTFGW"/>
              </xsl:with-param>
              <xsl:with-param name="strClass">cellTFGW</xsl:with-param>
            </xsl:call-template>

            <!-- Treasures 1 -->
            <tr>
              <td class="cellLabel">
                <xsl:value-of select="$Translations/msa:Translations/msa:*[local-name() = $LangCode]/msa:Talk"/>
              </td>
              <!-- Only display the Special Event information if:
                     1. It is an "All day Event" (no meetings)
                     2. It is a "Midweek Memorial Event" (no midweek meeting) -->
              <xsl:apply-templates select="MeetingWorkBook/Meeting[1]/SpecialEvent[Date/@AllDayEvent='1' or (Date/@MidweekEvent='1' and Date/@Memorial='1')]/Event" mode="FirstRow">
                <xsl:with-param name="strClass">cellBold borderRight</xsl:with-param>
              </xsl:apply-templates>
              <xsl:apply-templates select="MeetingWorkBook/Meeting[1]/TFGW/TFGWItem[1]/Name" mode="FirstRow">
                <xsl:with-param name="strClass">cellBold borderRight</xsl:with-param>
              </xsl:apply-templates>
              <xsl:apply-templates select="MeetingWorkBook/Meeting[2]/SpecialEvent[Date/@AllDayEvent='1' or (Date/@MidweekEvent='1' and Date/@Memorial='1')]/Event" mode="FirstRow">
                <xsl:with-param name="strClass">cellBold borderLeftRight</xsl:with-param>
              </xsl:apply-templates>
              <xsl:apply-templates select="MeetingWorkBook/Meeting[2]/TFGW/TFGWItem[1]/Name" mode="FirstRow">
                <xsl:with-param name="strClass">cellBold borderLeftRight</xsl:with-param>
              </xsl:apply-templates>
              <xsl:apply-templates select="MeetingWorkBook/Meeting[3]/SpecialEvent[Date/@AllDayEvent='1' or (Date/@MidweekEvent='1' and Date/@Memorial='1')]/Event" mode="FirstRow">
                <xsl:with-param name="strClass">cellBold borderLeftRight</xsl:with-param>
              </xsl:apply-templates>
              <xsl:apply-templates select="MeetingWorkBook/Meeting[3]/TFGW/TFGWItem[1]/Name" mode="FirstRow">
                <xsl:with-param name="strClass">cellBold borderLeftRight</xsl:with-param>
              </xsl:apply-templates>
              <xsl:choose>
                <xsl:when test="count(MeetingWorkBook/Meeting) = 4">
                  <xsl:apply-templates select="MeetingWorkBook/Meeting[4]/SpecialEvent[Date/@AllDayEvent='1' or (Date/@MidweekEvent='1' and Date/@Memorial='1')]/Event" mode="FirstRow">
                    <xsl:with-param name="strClass">cellBold borderLeft</xsl:with-param>
                  </xsl:apply-templates>
                  <xsl:apply-templates select="MeetingWorkBook/Meeting[4]/TFGW/TFGWItem[1]/Name" mode="FirstRow">
                    <xsl:with-param name="strClass">cellBold borderLeft</xsl:with-param>
                  </xsl:apply-templates>
                </xsl:when>
                <xsl:otherwise>
                  <xsl:apply-templates select="MeetingWorkBook/Meeting[4]/SpecialEvent[Date/@AllDayEvent='1' or (Date/@MidweekEvent='1' and Date/@Memorial='1')]/Event" mode="FirstRow">
                    <xsl:with-param name="strClass">cellBold borderLeftRight</xsl:with-param>
                  </xsl:apply-templates>
                  <xsl:apply-templates select="MeetingWorkBook/Meeting[4]/TFGW/TFGWItem[1]/Name" mode="FirstRow">
                    <xsl:with-param name="strClass">cellBold borderLeftRight</xsl:with-param>
                  </xsl:apply-templates>
                  <xsl:apply-templates select="MeetingWorkBook/Meeting[5]/SpecialEvent[Date/@AllDayEvent='1' or (Date/@MidweekEvent='1' and Date/@Memorial='1')]/Event" mode="FirstRow">
                    <xsl:with-param name="strClass">cellBold borderLeft</xsl:with-param>
                  </xsl:apply-templates>
                  <xsl:apply-templates select="MeetingWorkBook/Meeting[5]/TFGW/TFGWItem[1]/Name" mode="FirstRow">
                    <xsl:with-param name="strClass">cellBold borderLeft</xsl:with-param>
                  </xsl:apply-templates>
                </xsl:otherwise>
              </xsl:choose>
            </tr>

            <!-- Treasures 2 -->
            <tr>
              <td class="cellLabel">
                <xsl:value-of select="$Translations/msa:Translations/msa:*[local-name() = $LangCode]/msa:Digging"/>
              </td>
              <!-- The templates will only be applied if the specified nodes exist in the XML document.
              So there is no need to use multiple IF checks. -->
              <xsl:apply-templates select="MeetingWorkBook/Meeting[1]/TFGW/TFGWItem[2]/Name" mode="OtherRow">
                <xsl:with-param name="strClass">cellBold borderRightTopBottom</xsl:with-param>
              </xsl:apply-templates>
              <xsl:apply-templates select="MeetingWorkBook/Meeting[2]/TFGW/TFGWItem[2]/Name" mode="OtherRow">
                <xsl:with-param name="strClass">cellBold borderLeftRightTopBottom</xsl:with-param>
              </xsl:apply-templates>
              <xsl:apply-templates select="MeetingWorkBook/Meeting[3]/TFGW/TFGWItem[2]/Name" mode="OtherRow">
                <xsl:with-param name="strClass">cellBold borderLeftRightTopBottom</xsl:with-param>
              </xsl:apply-templates>
              <xsl:choose>
                <xsl:when test="count(MeetingWorkBook/Meeting) = 4">
                  <xsl:apply-templates select="MeetingWorkBook/Meeting[4]/TFGW/TFGWItem[2]/Name" mode="OtherRow">
                    <xsl:with-param name="strClass">cellBold borderLeftTopBottom</xsl:with-param>
                  </xsl:apply-templates>
                </xsl:when>
                <xsl:otherwise>
                  <xsl:apply-templates select="MeetingWorkBook/Meeting[4]/TFGW/TFGWItem[2]/Name" mode="OtherRow">
                    <xsl:with-param name="strClass">cellBold borderLeftRightTopBottom</xsl:with-param>
                  </xsl:apply-templates>
                  <xsl:apply-templates select="MeetingWorkBook/Meeting[5]/TFGW/TFGWItem[2]/Name" mode="OtherRow">
                    <xsl:with-param name="strClass">cellBold borderLeftTopBottom</xsl:with-param>
                  </xsl:apply-templates>
                </xsl:otherwise>
              </xsl:choose>
            </tr>

            <!-- Bible Reading -->
            <tr>
              <td class="cellLabel">
                <xsl:value-of select="$Translations/msa:Translations/msa:*[local-name() = $LangCode]/msa:BibleReading"/>
              </td>
              <!--The templates will only be applied if the specified nodes exist in the XML document.
              So there is no need to use multiple IF checks.-->
              <xsl:apply-templates select="MeetingWorkBook/Meeting[1]/TFGW/BibleReadingItem/Readers/Reader[@Class='1']" mode="OtherRow">
                <xsl:with-param name="strClass">borderRight</xsl:with-param>
              </xsl:apply-templates>
              <xsl:apply-templates select="MeetingWorkBook/Meeting[2]/TFGW/BibleReadingItem/Readers/Reader[@Class='1']" mode="OtherRow">
                <xsl:with-param name="strClass">borderLeftRight</xsl:with-param>
              </xsl:apply-templates>
              <xsl:apply-templates select="MeetingWorkBook/Meeting[3]/TFGW/BibleReadingItem/Readers/Reader[@Class='1']" mode="OtherRow">
                <xsl:with-param name="strClass">borderLeftRight</xsl:with-param>
              </xsl:apply-templates>
              <xsl:choose>
                <xsl:when test="count(MeetingWorkBook/Meeting) = 4">
                  <xsl:apply-templates select="MeetingWorkBook/Meeting[4]/TFGW/BibleReadingItem/Readers/Reader[@Class='1']" mode="OtherRow">
                    <xsl:with-param name="strClass">borderLeft</xsl:with-param>
                  </xsl:apply-templates>
                </xsl:when>
                <xsl:otherwise>
                  <xsl:apply-templates select="MeetingWorkBook/Meeting[4]/TFGW/BibleReadingItem/Readers/Reader[@Class='1']" mode="OtherRow">
                    <xsl:with-param name="strClass">borderLeftRight</xsl:with-param>
                  </xsl:apply-templates>
                  <xsl:apply-templates select="MeetingWorkBook/Meeting[5]/TFGW/BibleReadingItem/Readers/Reader[@Class='1']" mode="OtherRow">
                    <xsl:with-param name="strClass">borderLeft</xsl:with-param>
                  </xsl:apply-templates>
                </xsl:otherwise>
              </xsl:choose>
            </tr>

            <!-- Display the AYFM Heading -->
            <xsl:call-template name="Heading">
              <xsl:with-param name="strTitle">
                <xsl:value-of select="$Translations/msa:Translations/msa:*[local-name() = $LangCode]/msa:SectionAYFM"/>
              </xsl:with-param>
              <xsl:with-param name="strClass">cellAYFM</xsl:with-param>
            </xsl:call-template>

            <!-- Discussion with Video - Before -->
            <tr>
              <td class="cellLabel">
                <xsl:text>Discussion</xsl:text>
              </td>

              <!-- Week 1 -->
              <xsl:choose>
                <xsl:when test="count(MeetingWorkBook/Meeting[1]/AYFM/Teaching[@VideoAfterStudentItem='0']) >= 1">
                  <xsl:apply-templates select="MeetingWorkBook/Meeting[1]/AYFM/Teaching[@VideoAfterStudentItem='0']/Names/Name[@Class='1']" mode="FirstRow">
                    <xsl:with-param name="strClass">borderRightBottom</xsl:with-param>
                  </xsl:apply-templates>
                </xsl:when>
                <xsl:otherwise>
                  <td class="borderRightBottom">
                    <xsl:text> </xsl:text>
                  </td>
                </xsl:otherwise>
              </xsl:choose>

              <!-- Week 2 -->
              <xsl:choose>
                <xsl:when test="count(MeetingWorkBook/Meeting[2]/AYFM/Teaching[@VideoAfterStudentItem='0']) >= 1">
                  <xsl:apply-templates select="MeetingWorkBook/Meeting[2]/AYFM/Teaching[@VideoAfterStudentItem='0']/Names/Name[@Class='1']" mode="FirstRow">
                    <xsl:with-param name="strClass">borderLeftRightBottom</xsl:with-param>
                  </xsl:apply-templates>
                </xsl:when>
                <xsl:otherwise>
                  <td class="borderLeftRightBottom">
                    <xsl:text> </xsl:text>
                  </td>
                </xsl:otherwise>
              </xsl:choose>

              <!-- Week 3 -->
              <xsl:choose>
                <xsl:when test="count(MeetingWorkBook/Meeting[3]/AYFM/Teaching[@VideoAfterStudentItem='0']) >= 1">
                  <xsl:apply-templates select="MeetingWorkBook/Meeting[3]/AYFM/Teaching[@VideoAfterStudentItem='0']/Names/Name[@Class='1']" mode="FirstRow">
                    <xsl:with-param name="strClass">borderLeftRightBottom</xsl:with-param>
                  </xsl:apply-templates>
                </xsl:when>
                <xsl:otherwise>
                  <td class="borderLeftRightBottom">
                    <xsl:text> </xsl:text>
                  </td>
                </xsl:otherwise>
              </xsl:choose>

              <xsl:choose>
                <xsl:when test="count(MeetingWorkBook/Meeting) = 4">

                  <!-- Week 4 -->
                  <xsl:choose>
                    <xsl:when test="count(MeetingWorkBook/Meeting[4]/AYFM/Teaching[@VideoAfterStudentItem='0']) >= 1">
                      <xsl:apply-templates select="MeetingWorkBook/Meeting[4]/AYFM/Teaching[@VideoAfterStudentItem='0']/Names/Name[@Class='1']" mode="FirstRow">
                        <xsl:with-param name="strClass">borderLeftBottom</xsl:with-param>
                      </xsl:apply-templates>
                    </xsl:when>
                    <xsl:otherwise>
                      <td class="borderLeftBottom">
                        <xsl:text> </xsl:text>
                      </td>
                    </xsl:otherwise>
                  </xsl:choose>

                </xsl:when>
                <xsl:otherwise>

                  <!-- Week 4 -->
                  <xsl:choose>
                    <xsl:when test="count(MeetingWorkBook/Meeting[4]/AYFM/Teaching[@VideoAfterStudentItem='0']) >= 1">
                      <xsl:apply-templates select="MeetingWorkBook/Meeting[4]/AYFM/Teaching[@VideoAfterStudentItem='0']/Names/Name[@Class='1']" mode="FirstRow">
                        <xsl:with-param name="strClass">borderLeftRightBottom</xsl:with-param>
                      </xsl:apply-templates>
                    </xsl:when>
                    <xsl:otherwise>
                      <td class="borderLeftRightBottom">
                        <xsl:text> </xsl:text>
                      </td>
                    </xsl:otherwise>
                  </xsl:choose>

                  <!-- Week 5 -->
                  <xsl:choose>
                    <xsl:when test="count(MeetingWorkBook/Meeting[5]/AYFM/Teaching[@VideoAfterStudentItem='0']) >= 1">
                      <xsl:apply-templates select="MeetingWorkBook/Meeting[5]/AYFM/Teaching[@VideoAfterStudentItem='0']/Names/Name[@Class='1']" mode="FirstRow">
                        <xsl:with-param name="strClass">borderLeftBottom</xsl:with-param>
                      </xsl:apply-templates>
                    </xsl:when>
                    <xsl:otherwise>
                      <td class="borderLeftBottom">
                        <xsl:text> </xsl:text>
                      </td>
                    </xsl:otherwise>
                  </xsl:choose>

                </xsl:otherwise>
              </xsl:choose>
            </tr>

            <!--Student Item 1-->
            <tr>
              <td class="cellLabel">
                <xsl:value-of select="$Translations/msa:Translations/msa:*[local-name() = $LangCode]/msa:Item1"/>
              </td>
              <!-- Only display the Special Event information if:
                     1. It is an "All Day Event" (no meetings).
                     2. It is a "Midweek Memorial Event" (no midweek meeting) -->
              <!-- StudentItem or Teaching elements are only present in the data file if there is an actual "Midweek Meeting" for the week -->
              <xsl:apply-templates select="MeetingWorkBook/Meeting[1]/SpecialEvent[Date/@AllDayEvent='1' or (Date/@MidweekEvent='1' and Date/@Memorial='1')]/Event" mode="OtherRow">
                <xsl:with-param name="strClass">cellBold borderRight</xsl:with-param>
              </xsl:apply-templates>
              <xsl:apply-templates select="MeetingWorkBook/Meeting[1]/AYFM/StudentItem[1]/Students[@ChairmanHandleSampleVideo and @Class='1']">
                <xsl:with-param name="strClass">borderRight</xsl:with-param>
              </xsl:apply-templates>
              <xsl:apply-templates select="MeetingWorkBook/Meeting[1]/AYFM/StudentItem[1]/Students[@Class='1']/Student" mode="OtherRow">
                <xsl:with-param name="strClass">borderRight</xsl:with-param>
              </xsl:apply-templates>
              <xsl:apply-templates select="MeetingWorkBook/Meeting[2]/SpecialEvent[Date/@AllDayEvent='1' or (Date/@MidweekEvent='1' and Date/@Memorial='1')]/Event" mode="OtherRow">
                <xsl:with-param name="strClass">cellBold borderLeftRight</xsl:with-param>
              </xsl:apply-templates>
              <xsl:apply-templates select="MeetingWorkBook/Meeting[2]/AYFM/StudentItem[1]/Students[@ChairmanHandleSampleVideo and @Class='1']">
                <xsl:with-param name="strClass">borderLeftRight</xsl:with-param>
              </xsl:apply-templates>
              <xsl:apply-templates select="MeetingWorkBook/Meeting[2]/AYFM/StudentItem[1]/Students[@Class='1']/Student" mode="OtherRow">
                <xsl:with-param name="strClass">borderLeftRight</xsl:with-param>
              </xsl:apply-templates>
              <xsl:apply-templates select="MeetingWorkBook/Meeting[3]/SpecialEvent[Date/@AllDayEvent='1' or (Date/@MidweekEvent='1' and Date/@Memorial='1')]/Event" mode="OtherRow">
                <xsl:with-param name="strClass">cellBold borderLeftRight</xsl:with-param>
              </xsl:apply-templates>
              <xsl:apply-templates select="MeetingWorkBook/Meeting[3]/AYFM/StudentItem[1]/Students[@ChairmanHandleSampleVideo and @Class='1']">
                <xsl:with-param name="strClass">borderLeftRight</xsl:with-param>
              </xsl:apply-templates>
              <xsl:apply-templates select="MeetingWorkBook/Meeting[3]/AYFM/StudentItem[1]/Students[@Class='1']/Student" mode="OtherRow">
                <xsl:with-param name="strClass">borderLeftRight</xsl:with-param>
              </xsl:apply-templates>
              <xsl:choose>
                <xsl:when test="count(MeetingWorkBook/Meeting) = 4">
                  <xsl:apply-templates select="MeetingWorkBook/Meeting[4]/SpecialEvent[Date/@AllDayEvent='1' or (Date/@MidweekEvent='1' and Date/@Memorial='1')]/Event" mode="OtherRow">
                    <xsl:with-param name="strClass">cellBold borderLeft</xsl:with-param>
                  </xsl:apply-templates>
                  <xsl:apply-templates select="MeetingWorkBook/Meeting[4]/AYFM/StudentItem[1]/Students[@ChairmanHandleSampleVideo and @Class='1']">
                    <xsl:with-param name="strClass">borderLeft</xsl:with-param>
                  </xsl:apply-templates>
                  <xsl:apply-templates select="MeetingWorkBook/Meeting[4]/AYFM/StudentItem[1]/Students[@Class='1']/Student" mode="OtherRow">
                    <xsl:with-param name="strClass">borderLeft</xsl:with-param>
                  </xsl:apply-templates>
                </xsl:when>
                <xsl:otherwise>
                  <xsl:apply-templates select="MeetingWorkBook/Meeting[4]/SpecialEvent[Date/@AllDayEvent='1' or (Date/@MidweekEvent='1' and Date/@Memorial='1')]/Event" mode="OtherRow">
                    <xsl:with-param name="strClass">cellBold borderLeftRight</xsl:with-param>
                  </xsl:apply-templates>
                  <xsl:apply-templates select="MeetingWorkBook/Meeting[4]/AYFM/Teaching[@VideoAfterStudentItem='0']/Names/Name[@Class='1']" mode="OtherRow">
                    <xsl:with-param name="strClass">borderRight</xsl:with-param>
                  </xsl:apply-templates>
                  <xsl:apply-templates select="MeetingWorkBook/Meeting[4]/AYFM/StudentItem[1]/Students[@ChairmanHandleSampleVideo and @Class='1']">
                    <xsl:with-param name="strClass">borderLeftRight</xsl:with-param>
                  </xsl:apply-templates>
                  <xsl:apply-templates select="MeetingWorkBook/Meeting[4]/AYFM/StudentItem[1]/Students[@Class='1']/Student" mode="OtherRow">
                    <xsl:with-param name="strClass">borderLeftRight</xsl:with-param>
                  </xsl:apply-templates>
                  <xsl:apply-templates select="MeetingWorkBook/Meeting[5]/SpecialEvent[Date/@AllDayEvent='1' or (Date/@MidweekEvent='1' and Date/@Memorial='1')]/Event" mode="OtherRow">
                    <xsl:with-param name="strClass">cellBold borderLeft</xsl:with-param>
                  </xsl:apply-templates>
                  <xsl:apply-templates select="MeetingWorkBook/Meeting[5]/AYFM/Teaching[@VideoAfterStudentItem='0']/Names/Name[@Class='1']" mode="OtherRow">
                    <xsl:with-param name="strClass">borderRight</xsl:with-param>
                  </xsl:apply-templates>
                  <xsl:apply-templates select="MeetingWorkBook/Meeting[5]/AYFM/StudentItem[1]/Students[@ChairmanHandleSampleVideo and @Class='1']">
                    <xsl:with-param name="strClass">borderLeft</xsl:with-param>
                  </xsl:apply-templates>
                  <xsl:apply-templates select="MeetingWorkBook/Meeting[5]/AYFM/StudentItem[1]/Students[@Class='1']/Student" mode="OtherRow">
                    <xsl:with-param name="strClass">borderLeft</xsl:with-param>
                  </xsl:apply-templates>
                </xsl:otherwise>
              </xsl:choose>
            </tr>

            <!-- Student Item 2 -->
            <tr>
              <td class="cellLabel">
                <xsl:value-of select="$Translations/msa:Translations/msa:*[local-name() = $LangCode]/msa:Item2"/>
              </td>

              <!-- Week 1 -->
              <xsl:choose>
                <xsl:when test ="count(MeetingWorkBook/Meeting[1]/AYFM/StudentItem) >= 2">
                  <xsl:apply-templates select="MeetingWorkBook/Meeting[1]/AYFM/StudentItem[2]/Students[@ChairmanHandleSampleVideo and @Class='1']">
                    <xsl:with-param name="strClass">borderRightTopBottom</xsl:with-param>
                  </xsl:apply-templates>
                  <xsl:apply-templates select="MeetingWorkBook/Meeting[1]/AYFM/StudentItem[2]/Students[@Class='1']/Student" mode="OtherRow">
                    <xsl:with-param name="strClass">borderRightTopBottom</xsl:with-param>
                  </xsl:apply-templates>
                </xsl:when>
                <xsl:otherwise>
                  <td class="borderRightTopBottom">
                    <xsl:text> </xsl:text>
                  </td>
                </xsl:otherwise>
              </xsl:choose>

              <!-- Week 2 -->
              <xsl:choose>
                <xsl:when test ="count(MeetingWorkBook/Meeting[2]/AYFM/StudentItem) >= 2">
                  <xsl:apply-templates select="MeetingWorkBook/Meeting[2]/AYFM/StudentItem[2]/Students[@ChairmanHandleSampleVideo and @Class='1']">
                    <xsl:with-param name="strClass">borderLeftRightTopBottom</xsl:with-param>
                  </xsl:apply-templates>
                  <xsl:apply-templates select="MeetingWorkBook/Meeting[2]/AYFM/StudentItem[2]/Students[@Class='1']/Student" mode="OtherRow">
                    <xsl:with-param name="strClass">borderLeftRightTopBottom</xsl:with-param>
                  </xsl:apply-templates>
                </xsl:when>
                <xsl:otherwise>
                  <td class="borderLeftRightTopBottom">
                    <xsl:text> </xsl:text>
                  </td>
                </xsl:otherwise>
              </xsl:choose>

              <!-- Week 3 -->
              <xsl:choose>
                <xsl:when test ="count(MeetingWorkBook/Meeting[3]/AYFM/StudentItem) >= 2">
                  <xsl:apply-templates select="MeetingWorkBook/Meeting[3]/AYFM/StudentItem[2]/Students[@ChairmanHandleSampleVideo and @Class='1']">
                    <xsl:with-param name="strClass">borderLeftRightTopBottom</xsl:with-param>
                  </xsl:apply-templates>
                  <xsl:apply-templates select="MeetingWorkBook/Meeting[3]/AYFM/StudentItem[2]/Students[@Class='1']/Student" mode="OtherRow">
                    <xsl:with-param name="strClass">borderLeftRightTopBottom</xsl:with-param>
                  </xsl:apply-templates>
                </xsl:when>
                <xsl:otherwise>
                  <td class="borderLeftRightTopBottom">
                    <xsl:text> </xsl:text>
                  </td>
                </xsl:otherwise>
              </xsl:choose>

              <xsl:choose>
                <xsl:when test="count(MeetingWorkBook/Meeting) = 4">

                  <!-- Week 4 -->
                  <xsl:choose>
                    <xsl:when test ="count(MeetingWorkBook/Meeting[4]/AYFM/StudentItem) >= 2">
                      <xsl:apply-templates select="MeetingWorkBook/Meeting[4]/AYFM/StudentItem[2]/Students[@ChairmanHandleSampleVideo and @Class='1']">
                        <xsl:with-param name="strClass">borderLeftTopBottom</xsl:with-param>
                      </xsl:apply-templates>
                      <xsl:apply-templates select="MeetingWorkBook/Meeting[4]/AYFM/StudentItem[2]/Students[@Class='1']/Student" mode="OtherRow">
                        <xsl:with-param name="strClass">borderLeftTopBottom</xsl:with-param>
                      </xsl:apply-templates>
                    </xsl:when>
                    <xsl:otherwise>
                      <td class="borderLeftTopBottom">
                        <xsl:text> </xsl:text>
                      </td>
                    </xsl:otherwise>
                  </xsl:choose>

                </xsl:when>
                <xsl:otherwise>

                  <!-- Week 4 -->
                  <xsl:choose>
                    <xsl:when test ="count(MeetingWorkBook/Meeting[4]/AYFM/StudentItem) >= 2">
                      <xsl:apply-templates select="MeetingWorkBook/Meeting[4]/AYFM/StudentItem[2]/Students[@ChairmanHandleSampleVideo and @Class='1']">
                        <xsl:with-param name="strClass">borderLeftRightTopBottom</xsl:with-param>
                      </xsl:apply-templates>
                      <xsl:apply-templates select="MeetingWorkBook/Meeting[4]/AYFM/StudentItem[2]/Students[@Class='1']/Student" mode="OtherRow">
                        <xsl:with-param name="strClass">borderLeftRightTopBottom</xsl:with-param>
                      </xsl:apply-templates>
                    </xsl:when>
                    <xsl:otherwise>
                      <td class="borderLeftRightTopBottom">
                        <xsl:text> </xsl:text>
                      </td>
                    </xsl:otherwise>
                  </xsl:choose>

                  <!-- Week 5 -->
                  <xsl:choose>
                    <xsl:when test ="count(MeetingWorkBook/Meeting[5]/AYFM/StudentItem) >= 2">
                      <xsl:apply-templates select="MeetingWorkBook/Meeting[5]/AYFM/StudentItem[2]/Students[@ChairmanHandleSampleVideo and @Class='1']">
                        <xsl:with-param name="strClass">borderLeftTopBottom</xsl:with-param>
                      </xsl:apply-templates>
                      <xsl:apply-templates select="MeetingWorkBook/Meeting[5]/AYFM/StudentItem[2]/Students[@Class='1']/Student" mode="OtherRow">
                        <xsl:with-param name="strClass">borderLeftTopBottom</xsl:with-param>
                      </xsl:apply-templates>
                    </xsl:when>
                    <xsl:otherwise>
                      <td class="borderLeftTopBottom">
                        <xsl:text> </xsl:text>
                      </td>
                    </xsl:otherwise>
                  </xsl:choose>

                </xsl:otherwise>
              </xsl:choose>
            </tr>

            <!-- Student Item 3 -->
            <tr>
              <td class="cellLabel">
                <xsl:value-of select="$Translations/msa:Translations/msa:*[local-name() = $LangCode]/msa:Item3"/>
              </td>

              <!-- Week 1 -->
              <xsl:choose>
                <xsl:when test ="count(MeetingWorkBook/Meeting[1]/AYFM/StudentItem) >= 3">
                  <xsl:apply-templates select="MeetingWorkBook/Meeting[1]/AYFM/StudentItem[3]/Students[@ChairmanHandleSampleVideo and @Class='1']">
                    <xsl:with-param name="strClass">borderRightTopBottom</xsl:with-param>
                  </xsl:apply-templates>
                  <xsl:apply-templates select="MeetingWorkBook/Meeting[1]/AYFM/StudentItem[3]/Students[@Class='1']/Student" mode="OtherRow">
                    <xsl:with-param name="strClass">borderRightTopBottom</xsl:with-param>
                  </xsl:apply-templates>
                </xsl:when>
                <xsl:otherwise>
                  <td class="borderRightTopBottom">
                    <xsl:text> </xsl:text>
                  </td>
                </xsl:otherwise>
              </xsl:choose>

              <!-- Week 2 -->
              <xsl:choose>
                <xsl:when test ="count(MeetingWorkBook/Meeting[2]/AYFM/StudentItem) >= 3">
                  <xsl:apply-templates select="MeetingWorkBook/Meeting[2]/AYFM/StudentItem[3]/Students[@ChairmanHandleSampleVideo and @Class='1']">
                    <xsl:with-param name="strClass">borderLeftRightTopBottom</xsl:with-param>
                  </xsl:apply-templates>
                  <xsl:apply-templates select="MeetingWorkBook/Meeting[2]/AYFM/StudentItem[3]/Students[@Class='1']/Student" mode="OtherRow">
                    <xsl:with-param name="strClass">borderLeftRightTopBottom</xsl:with-param>
                  </xsl:apply-templates>
                </xsl:when>
                <xsl:otherwise>
                  <td class="borderLeftRightTopBottom">
                    <xsl:text> </xsl:text>
                  </td>
                </xsl:otherwise>
              </xsl:choose>

              <!-- Week 3 -->
              <xsl:choose>
                <xsl:when test ="count(MeetingWorkBook/Meeting[3]/AYFM/StudentItem) >= 3">
                  <xsl:apply-templates select="MeetingWorkBook/Meeting[3]/AYFM/StudentItem[3]/Students[@ChairmanHandleSampleVideo and @Class='1']">
                    <xsl:with-param name="strClass">borderLeftRightTopBottom</xsl:with-param>
                  </xsl:apply-templates>
                  <xsl:apply-templates select="MeetingWorkBook/Meeting[3]/AYFM/StudentItem[3]/Students[@Class='1']/Student" mode="OtherRow">
                    <xsl:with-param name="strClass">borderLeftRightTopBottom</xsl:with-param>
                  </xsl:apply-templates>
                </xsl:when>
                <xsl:otherwise>
                  <td class="borderLeftRightTopBottom">
                    <xsl:text> </xsl:text>
                  </td>
                </xsl:otherwise>
              </xsl:choose>

              <xsl:choose>
                <xsl:when test="count(MeetingWorkBook/Meeting) = 4">

                  <!-- Week 4 -->
                  <xsl:choose>
                    <xsl:when test ="count(MeetingWorkBook/Meeting[4]/AYFM/StudentItem) >= 3">
                      <xsl:apply-templates select="MeetingWorkBook/Meeting[4]/AYFM/StudentItem[3]/Students[@ChairmanHandleSampleVideo and @Class='1']">
                        <xsl:with-param name="strClass">borderLeftTopBottom</xsl:with-param>
                      </xsl:apply-templates>
                      <xsl:apply-templates select="MeetingWorkBook/Meeting[4]/AYFM/StudentItem[3]/Students[@Class='1']/Student" mode="OtherRow">
                        <xsl:with-param name="strClass">borderLeftTopBottom</xsl:with-param>
                      </xsl:apply-templates>
                    </xsl:when>
                    <xsl:otherwise>
                      <td class="borderLeftTopBottom">
                        <xsl:text> </xsl:text>
                      </td>
                    </xsl:otherwise>
                  </xsl:choose>

                </xsl:when>
                <xsl:otherwise>

                  <!-- Week 4 -->
                  <xsl:choose>
                    <xsl:when test ="count(MeetingWorkBook/Meeting[4]/AYFM/StudentItem) >= 3">
                      <xsl:apply-templates select="MeetingWorkBook/Meeting[4]/AYFM/StudentItem[3]/Students[@ChairmanHandleSampleVideo and @Class='1']">
                        <xsl:with-param name="strClass">borderLeftRightTopBottom</xsl:with-param>
                      </xsl:apply-templates>
                      <xsl:apply-templates select="MeetingWorkBook/Meeting[4]/AYFM/StudentItem[3]/Students[@Class='1']/Student" mode="OtherRow">
                        <xsl:with-param name="strClass">borderLeftRightTopBottom</xsl:with-param>
                      </xsl:apply-templates>
                    </xsl:when>
                    <xsl:otherwise>
                      <td class="borderLeftRightTopBottom">
                        <xsl:text> </xsl:text>
                      </td>
                    </xsl:otherwise>
                  </xsl:choose>

                  <!-- Week 5 -->
                  <xsl:choose>
                    <xsl:when test ="count(MeetingWorkBook/Meeting[5]/AYFM/StudentItem) >= 3">
                      <xsl:apply-templates select="MeetingWorkBook/Meeting[5]/AYFM/StudentItem[3]/Students[@ChairmanHandleSampleVideo and @Class='1']">
                        <xsl:with-param name="strClass">borderLeftTopBottom</xsl:with-param>
                      </xsl:apply-templates>
                      <xsl:apply-templates select="MeetingWorkBook/Meeting[5]/AYFM/StudentItem[3]/Students[@Class='1']/Student" mode="OtherRow">
                        <xsl:with-param name="strClass">borderLeftTopBottom</xsl:with-param>
                      </xsl:apply-templates>
                    </xsl:when>
                    <xsl:otherwise>
                      <td class="borderLeftTopBottom">
                        <xsl:text> </xsl:text>
                      </td>
                    </xsl:otherwise>
                  </xsl:choose>

                </xsl:otherwise>
              </xsl:choose>
            </tr>

            <!-- Student Item 4 -->
            <tr>
              <td class="cellLabel">
                <xsl:value-of select="$Translations/msa:Translations/msa:*[local-name() = $LangCode]/msa:Item4"/>
              </td>

              <!-- Week 1 -->
              <xsl:choose>
                <xsl:when test ="count(MeetingWorkBook/Meeting[1]/AYFM/StudentItem) = 4">
                  <xsl:apply-templates select="MeetingWorkBook/Meeting[1]/AYFM/StudentItem[4]/Students[@ChairmanHandleSampleVideo and @Class='1']">
                    <xsl:with-param name="strClass">borderRightTopBottom</xsl:with-param>
                  </xsl:apply-templates>
                  <xsl:apply-templates select="MeetingWorkBook/Meeting[1]/AYFM/StudentItem[4]/Students[@Class='1']/Student" mode="OtherRow">
                    <xsl:with-param name="strClass">borderRightTopBottom</xsl:with-param>
                  </xsl:apply-templates>
                </xsl:when>
                <xsl:otherwise>
                  <td class="borderRightTopBottom">
                    <xsl:text> </xsl:text>
                  </td>
                </xsl:otherwise>
              </xsl:choose>

              <!-- Week 2 -->
              <xsl:choose>
                <xsl:when test ="count(MeetingWorkBook/Meeting[2]/AYFM/StudentItem) = 4">
                  <xsl:apply-templates select="MeetingWorkBook/Meeting[2]/AYFM/StudentItem[4]/Students[@ChairmanHandleSampleVideo and @Class='1']">
                    <xsl:with-param name="strClass">borderLeftRightTopBottom</xsl:with-param>
                  </xsl:apply-templates>
                  <xsl:apply-templates select="MeetingWorkBook/Meeting[2]/AYFM/StudentItem[4]/Students[@Class='1']/Student" mode="OtherRow">
                    <xsl:with-param name="strClass">borderLeftRightTopBottom</xsl:with-param>
                  </xsl:apply-templates>
                </xsl:when>
                <xsl:otherwise>
                  <td class="borderLeftRightTopBottom">
                    <xsl:text> </xsl:text>
                  </td>
                </xsl:otherwise>
              </xsl:choose>

              <!-- Week 3 -->
              <xsl:choose>
                <xsl:when test ="count(MeetingWorkBook/Meeting[3]/AYFM/StudentItem) = 4">
                  <xsl:apply-templates select="MeetingWorkBook/Meeting[3]/AYFM/StudentItem[4]/Students[@ChairmanHandleSampleVideo and @Class='1']">
                    <xsl:with-param name="strClass">borderLeftRightTopBottom</xsl:with-param>
                  </xsl:apply-templates>
                  <xsl:apply-templates select="MeetingWorkBook/Meeting[3]/AYFM/StudentItem[4]/Students[@Class='1']/Student" mode="OtherRow">
                    <xsl:with-param name="strClass">borderLeftRightTopBottom</xsl:with-param>
                  </xsl:apply-templates>
                </xsl:when>
                <xsl:otherwise>
                  <td class="borderLeftRightTopBottom">
                    <xsl:text> </xsl:text>
                  </td>
                </xsl:otherwise>
              </xsl:choose>

              <xsl:choose>
                <xsl:when test="count(MeetingWorkBook/Meeting) = 4">

                  <!-- Week 4 -->
                  <xsl:choose>
                    <xsl:when test ="count(MeetingWorkBook/Meeting[4]/AYFM/StudentItem) = 4">
                      <xsl:apply-templates select="MeetingWorkBook/Meeting[4]/AYFM/StudentItem[4]/Students[@ChairmanHandleSampleVideo and @Class='1']">
                        <xsl:with-param name="strClass">borderLeftTopBottom</xsl:with-param>
                      </xsl:apply-templates>
                      <xsl:apply-templates select="MeetingWorkBook/Meeting[4]/AYFM/StudentItem[4]/Students[@Class='1']/Student" mode="OtherRow">
                        <xsl:with-param name="strClass">borderLeftTopBottom</xsl:with-param>
                      </xsl:apply-templates>
                    </xsl:when>
                    <xsl:otherwise>
                      <td class="borderLeftTopBottom">
                        <xsl:text> </xsl:text>
                      </td>
                    </xsl:otherwise>
                  </xsl:choose>

                </xsl:when>
                <xsl:otherwise>

                  <!-- Week 4 -->
                  <xsl:choose>
                    <xsl:when test ="count(MeetingWorkBook/Meeting[4]/AYFM/StudentItem) = 4">
                      <xsl:apply-templates select="MeetingWorkBook/Meeting[4]/AYFM/StudentItem[4]/Students[@ChairmanHandleSampleVideo and @Class='1']">
                        <xsl:with-param name="strClass">borderLeftRightTopBottom</xsl:with-param>
                      </xsl:apply-templates>
                      <xsl:apply-templates select="MeetingWorkBook/Meeting[4]/AYFM/StudentItem[4]/Students[@Class='1']/Student" mode="OtherRow">
                        <xsl:with-param name="strClass">borderLeftRightTopBottom</xsl:with-param>
                      </xsl:apply-templates>
                    </xsl:when>
                    <xsl:otherwise>
                      <td class="borderLeftRightTopBottom">
                        <xsl:text> </xsl:text>
                      </td>
                    </xsl:otherwise>
                  </xsl:choose>

                  <!-- Week 5 -->
                  <xsl:choose>
                    <xsl:when test ="count(MeetingWorkBook/Meeting[5]/AYFM/StudentItem) = 4">
                      <xsl:apply-templates select="MeetingWorkBook/Meeting[5]/AYFM/StudentItem[4]/Students[@ChairmanHandleSampleVideo and @Class='1']">
                        <xsl:with-param name="strClass">borderLeftTopBottom</xsl:with-param>
                      </xsl:apply-templates>
                      <xsl:apply-templates select="MeetingWorkBook/Meeting[5]/AYFM/StudentItem[4]/Students[@Class='1']/Student" mode="OtherRow">
                        <xsl:with-param name="strClass">borderLeftTopBottom</xsl:with-param>
                      </xsl:apply-templates>
                    </xsl:when>
                    <xsl:otherwise>
                      <td class="borderLeftTopBottom">
                        <xsl:text> </xsl:text>
                      </td>
                    </xsl:otherwise>
                  </xsl:choose>

                </xsl:otherwise>
              </xsl:choose>
            </tr>

            <!-- Discussion with Video - After -->
            <tr>
              <td class="cellLabel">
                <xsl:text>Discussion</xsl:text>
              </td>

              <!-- Week 1 -->
              <xsl:choose>
                <xsl:when test="count(MeetingWorkBook/Meeting[1]/AYFM/Teaching[@VideoAfterStudentItem='1']) >= 1">
                  <xsl:apply-templates select="MeetingWorkBook/Meeting[1]/AYFM/Teaching[@VideoAfterStudentItem='1']/Names/Name[@Class='1']" mode="OtherRow">
                    <xsl:with-param name="strClass">borderRight</xsl:with-param>
                  </xsl:apply-templates>
                </xsl:when>
                <xsl:otherwise>
                  <td class="borderRight">
                    <xsl:text> </xsl:text>
                  </td>
                </xsl:otherwise>
              </xsl:choose>

              <!-- Week 2 -->
              <xsl:choose>
                <xsl:when test="count(MeetingWorkBook/Meeting[2]/AYFM/Teaching[@VideoAfterStudentItem='1']) >= 1">
                  <xsl:apply-templates select="MeetingWorkBook/Meeting[2]/AYFM/Teaching[@VideoAfterStudentItem='1']/Names/Name[@Class='1']" mode="OtherRow">
                    <xsl:with-param name="strClass">borderLeftRight</xsl:with-param>
                  </xsl:apply-templates>
                </xsl:when>
                <xsl:otherwise>
                  <td class="borderLeftRight">
                    <xsl:text> </xsl:text>
                  </td>
                </xsl:otherwise>
              </xsl:choose>

              <!-- Week 3 -->
              <xsl:choose>
                <xsl:when test="count(MeetingWorkBook/Meeting[3]/AYFM/Teaching[@VideoAfterStudentItem='1']) >= 1">
                  <xsl:apply-templates select="MeetingWorkBook/Meeting[3]/AYFM/Teaching[@VideoAfterStudentItem='1']/Names/Name[@Class='1']" mode="OtherRow">
                    <xsl:with-param name="strClass">borderLeftRight</xsl:with-param>
                  </xsl:apply-templates>
                </xsl:when>
                <xsl:otherwise>
                  <td class="borderLeftRight">
                    <xsl:text> </xsl:text>
                  </td>
                </xsl:otherwise>
              </xsl:choose>

              <xsl:choose>
                <xsl:when test="count(MeetingWorkBook/Meeting) = 4">

                  <!-- Week 4 -->
                  <xsl:choose>
                    <xsl:when test="count(MeetingWorkBook/Meeting[4]/AYFM/Teaching[@VideoAfterStudentItem='1']) >= 1">
                      <xsl:apply-templates select="MeetingWorkBook/Meeting[4]/AYFM/Teaching[@VideoAfterStudentItem='1']/Names/Name[@Class='1']" mode="OtherRow">
                        <xsl:with-param name="strClass">borderLeft</xsl:with-param>
                      </xsl:apply-templates>
                    </xsl:when>
                    <xsl:otherwise>
                      <td class="borderLeft">
                        <xsl:text> </xsl:text>
                      </td>
                    </xsl:otherwise>
                  </xsl:choose>

                </xsl:when>
                <xsl:otherwise>

                  <!-- Week 4 -->
                  <xsl:choose>
                    <xsl:when test="count(MeetingWorkBook/Meeting[4]/AYFM/Teaching[@VideoAfterStudentItem='1']) >= 1">
                      <xsl:apply-templates select="MeetingWorkBook/Meeting[4]/AYFM/Teaching[@VideoAfterStudentItem='1']/Names/Name[@Class='1']" mode="OtherRow">
                        <xsl:with-param name="strClass">borderLeftRight</xsl:with-param>
                      </xsl:apply-templates>
                    </xsl:when>
                    <xsl:otherwise>
                      <td class="borderLeftRight">
                        <xsl:text> </xsl:text>
                      </td>
                    </xsl:otherwise>
                  </xsl:choose>

                  <!-- Week 5 -->
                  <xsl:choose>
                    <xsl:when test="count(MeetingWorkBook/Meeting[5]/AYFM/Teaching[@VideoAfterStudentItem='1']) >= 1">
                      <xsl:apply-templates select="MeetingWorkBook/Meeting[5]/AYFM/Teaching[@VideoAfterStudentItem='1']/Names/Name[@Class='1']" mode="OtherRow">
                        <xsl:with-param name="strClass">borderLeft</xsl:with-param>
                      </xsl:apply-templates>
                    </xsl:when>
                    <xsl:otherwise>
                      <td class="borderLeft">
                        <xsl:text> </xsl:text>
                      </td>
                    </xsl:otherwise>
                  </xsl:choose>

                </xsl:otherwise>
              </xsl:choose>
            </tr>

            <!-- Display the LAC Heading -->
            <xsl:call-template name="Heading">
              <xsl:with-param name="strTitle">
                <xsl:value-of select="$Translations/msa:Translations/msa:*[local-name() = $LangCode]/msa:SectionLAC"/>
              </xsl:with-param>
              <xsl:with-param name="strClass">cellLAC</xsl:with-param>
            </xsl:call-template>

            <!-- Living 1 Theme -->
            <tr>
              <td class="cellLabel" rowspan="2">
                <xsl:value-of select="$Translations/msa:Translations/msa:*[local-name() = $LangCode]/msa:LACItem1"/>
              </td>
              <!-- Only display the Special Event information if:
                     1. It is an "All Day Event" (no meetings).
                     2. It is a "Midweek Memorial Event" (no midweek meeting) -->
              <!-- LACItem elements are only present in the data file if there is an actual "Midweek Meeting" for the week -->
              <xsl:apply-templates select="MeetingWorkBook/Meeting[1]/SpecialEvent[Date/@AllDayEvent='1' or (Date/@MidweekEvent='1' and Date/@Memorial='1')]/Event">
                <xsl:with-param name="strClass">borderRightBottom</xsl:with-param>
              </xsl:apply-templates>
              <xsl:apply-templates select="MeetingWorkBook/Meeting[1]/LAC/LACItem[1]/Theme">
                <xsl:with-param name="strClass">borderRight</xsl:with-param>
              </xsl:apply-templates>
              <xsl:apply-templates select="MeetingWorkBook/Meeting[2]/SpecialEvent[Date/@AllDayEvent='1' or (Date/@MidweekEvent='1' and Date/@Memorial='1')]/Event">
                <xsl:with-param name="strClass">borderLeftRightBottom</xsl:with-param>
              </xsl:apply-templates>
              <xsl:apply-templates select="MeetingWorkBook/Meeting[2]/LAC/LACItem[1]/Theme">
                <xsl:with-param name="strClass">borderLeftRight</xsl:with-param>
              </xsl:apply-templates>
              <xsl:apply-templates select="MeetingWorkBook/Meeting[3]/SpecialEvent[Date/@AllDayEvent='1' or (Date/@MidweekEvent='1' and Date/@Memorial='1')]/Event">
                <xsl:with-param name="strClass">borderLeftRightBottom</xsl:with-param>
              </xsl:apply-templates>
              <xsl:apply-templates select="MeetingWorkBook/Meeting[3]/LAC/LACItem[1]/Theme">
                <xsl:with-param name="strClass">borderLeftRight</xsl:with-param>
              </xsl:apply-templates>
              <xsl:choose>
                <xsl:when test="count(MeetingWorkBook/Meeting) = 4">
                  <xsl:apply-templates select="MeetingWorkBook/Meeting[4]/SpecialEvent[Date/@AllDayEvent='1' or (Date/@MidweekEvent='1' and Date/@Memorial='1')]/Event">
                    <xsl:with-param name="strClass">borderLeftBottom</xsl:with-param>
                  </xsl:apply-templates>
                  <xsl:apply-templates select="MeetingWorkBook/Meeting[4]/LAC/LACItem[1]/Theme">
                    <xsl:with-param name="strClass">borderLeft</xsl:with-param>
                  </xsl:apply-templates>
                </xsl:when>
                <xsl:otherwise>
                  <xsl:apply-templates select="MeetingWorkBook/Meeting[4]/SpecialEvent[Date/@AllDayEvent='1' or (Date/@MidweekEvent='1' and Date/@Memorial='1')]/Event">
                    <xsl:with-param name="strClass">borderLeftRightBottom</xsl:with-param>
                  </xsl:apply-templates>
                  <xsl:apply-templates select="MeetingWorkBook/Meeting[4]/LAC/LACItem[1]/Theme">
                    <xsl:with-param name="strClass">borderLeftRight</xsl:with-param>
                  </xsl:apply-templates>
                  <xsl:apply-templates select="MeetingWorkBook/Meeting[5]/SpecialEvent[Date/@AllDayEvent='1' or (Date/@MidweekEvent='1' and Date/@Memorial='1')]/Event">
                    <xsl:with-param name="strClass">borderLeftBottom</xsl:with-param>
                  </xsl:apply-templates>
                  <xsl:apply-templates select="MeetingWorkBook/Meeting[5]/LAC/LACItem[1]/Theme">
                    <xsl:with-param name="strClass">borderLeft</xsl:with-param>
                  </xsl:apply-templates>
                </xsl:otherwise>
              </xsl:choose>
            </tr>

            <!-- Living 1 Time and Name -->
            <tr>
              <xsl:apply-templates select="MeetingWorkBook/Meeting[1]/LAC/LACItem[1]">
                <xsl:with-param name="strClass">borderRightBottom</xsl:with-param>
              </xsl:apply-templates>
              <xsl:apply-templates select="MeetingWorkBook/Meeting[2]/LAC/LACItem[1]">
                <xsl:with-param name="strClass">borderLeftRightBottom</xsl:with-param>
              </xsl:apply-templates>
              <xsl:apply-templates select="MeetingWorkBook/Meeting[3]/LAC/LACItem[1]">
                <xsl:with-param name="strClass">borderLeftRightBottom</xsl:with-param>
              </xsl:apply-templates>
              <xsl:choose>
                <xsl:when test="count(MeetingWorkBook/Meeting) = 4">
                  <xsl:apply-templates select="MeetingWorkBook/Meeting[4]/LAC/LACItem[1]">
                    <xsl:with-param name="strClass">borderLeftBottom</xsl:with-param>
                  </xsl:apply-templates>
                </xsl:when>
                <xsl:otherwise>
                  <xsl:apply-templates select="MeetingWorkBook/Meeting[4]/LAC/LACItem[1]">
                    <xsl:with-param name="strClass">borderLeftRightBottom</xsl:with-param>
                  </xsl:apply-templates>
                  <xsl:apply-templates select="MeetingWorkBook/Meeting[5]/LAC/LACItem[1]">
                    <xsl:with-param name="strClass">borderLeftBottom</xsl:with-param>
                  </xsl:apply-templates>
                </xsl:otherwise>
              </xsl:choose>
            </tr>

            <!-- Living 2 Theme -->
            <xsl:if test="count(MeetingWorkBook/Meeting[1]/LAC/LACItem) = 2 or 
				count(MeetingWorkBook/Meeting[2]/LAC/LACItem) = 2 or 
				count(MeetingWorkBook/Meeting[3]/LAC/LACItem) = 2 or 
				count(MeetingWorkBook/Meeting[4]/LAC/LACItem) = 2 or 
				count(MeetingWorkBook/Meeting[5]/LAC/LACItem) = 2">
              <tr>
                <td class="cellLabel" rowspan="2">
                  <xsl:value-of select="$Translations/msa:Translations/msa:*[local-name() = $LangCode]/msa:LACItem2"/>
                </td>
                <!--The templates will only be applied if the specified nodes exist in the XML document.
                So there is no need to use multiple IF checks.-->
                <xsl:choose>
                  <xsl:when test="count(MeetingWorkBook/Meeting[1]/LAC/LACItem) = 2">
                    <xsl:apply-templates select="MeetingWorkBook/Meeting[1]/LAC/LACItem[2]/Theme">
                      <xsl:with-param name="strClass">borderRight</xsl:with-param>
                    </xsl:apply-templates>
                  </xsl:when>
                  <xsl:when test="MeetingWorkBook/Meeting[1]/@SpecialEvent=0">
                    <td rowspan="2" class="borderRightBottom">
                      <xsl:text> </xsl:text>
                    </td>
                  </xsl:when>
                </xsl:choose>
                <xsl:choose>
                  <xsl:when test="count(MeetingWorkBook/Meeting[2]/LAC/LACItem) = 2">
                    <xsl:apply-templates select="MeetingWorkBook/Meeting[2]/LAC/LACItem[2]/Theme">
                      <xsl:with-param name="strClass">borderLeftRight</xsl:with-param>
                    </xsl:apply-templates>
                  </xsl:when>
                  <xsl:when test="MeetingWorkBook/Meeting[2]/@SpecialEvent=0">
                    <td rowspan="2" class="borderLeftRightBottom">
                      <xsl:text> </xsl:text>
                    </td>
                  </xsl:when>
                </xsl:choose>
                <xsl:choose>
                  <xsl:when test="count(MeetingWorkBook/Meeting[3]/LAC/LACItem) = 2">
                    <xsl:apply-templates select="MeetingWorkBook/Meeting[3]/LAC/LACItem[2]/Theme">
                      <xsl:with-param name="strClass">borderLeftRight</xsl:with-param>
                    </xsl:apply-templates>
                  </xsl:when>
                  <xsl:when test="MeetingWorkBook/Meeting[3]/@SpecialEvent=0">
                    <td rowspan="2" class="borderLeftRightBottom">
                      <xsl:text> </xsl:text>
                    </td>
                  </xsl:when>
                </xsl:choose>
                <xsl:choose>
                  <xsl:when test="count(MeetingWorkBook/Meeting) = 4">
                    <xsl:choose>
                      <xsl:when test="count(MeetingWorkBook/Meeting[4]/LAC/LACItem) = 2">
                        <xsl:apply-templates select="MeetingWorkBook/Meeting[4]/LAC/LACItem[2]/Theme">
                          <xsl:with-param name="strClass">borderLeft</xsl:with-param>
                        </xsl:apply-templates>
                      </xsl:when>
                      <xsl:when test="MeetingWorkBook/Meeting[4]/@SpecialEvent=0">
                        <td rowspan="2" class="borderLeftBottom">
                          <xsl:text> </xsl:text>
                        </td>
                      </xsl:when>
                    </xsl:choose>
                  </xsl:when>
                  <xsl:otherwise>
                    <xsl:choose>
                      <xsl:when test="count(MeetingWorkBook/Meeting[4]/LAC/LACItem) = 2">
                        <xsl:apply-templates select="MeetingWorkBook/Meeting[4]/LAC/LACItem[2]/Theme">
                          <xsl:with-param name="strClass">borderLeftRight</xsl:with-param>
                        </xsl:apply-templates>
                      </xsl:when>
                      <xsl:when test="MeetingWorkBook/Meeting[4]/@SpecialEvent=0">
                        <td rowspan="2" class="borderLeftRightBottom">
                          <xsl:text> </xsl:text>
                        </td>
                      </xsl:when>
                    </xsl:choose>
                    <xsl:choose>
                      <xsl:when test="count(MeetingWorkBook/Meeting[5]/LAC/LACItem) = 2">
                        <xsl:apply-templates select="MeetingWorkBook/Meeting[5]/LAC/LACItem[2]/Theme">
                          <xsl:with-param name="strClass">borderLeft</xsl:with-param>
                        </xsl:apply-templates>
                      </xsl:when>
                      <xsl:when test="MeetingWorkBook/Meeting[5]/@SpecialEvent=0">
                        <td rowspan="2" class="borderLeftBottom">
                          <xsl:text> </xsl:text>
                        </td>
                      </xsl:when>
                    </xsl:choose>
                  </xsl:otherwise>
                </xsl:choose>
              </tr>

              <!-- Living 2 Time and Name -->
              <tr>
                <xsl:apply-templates select="MeetingWorkBook/Meeting[1]/LAC/LACItem[2]">
                  <xsl:with-param name="strClass">borderRightBottom</xsl:with-param>
                </xsl:apply-templates>
                <xsl:apply-templates select="MeetingWorkBook/Meeting[2]/LAC/LACItem[2]">
                  <xsl:with-param name="strClass">borderLeftRightBottom</xsl:with-param>
                </xsl:apply-templates>
                <xsl:apply-templates select="MeetingWorkBook/Meeting[3]/LAC/LACItem[2]">
                  <xsl:with-param name="strClass">borderLeftRightBottom</xsl:with-param>
                </xsl:apply-templates>
                <xsl:choose>
                  <xsl:when test="count(MeetingWorkBook/Meeting) = 4">
                    <xsl:apply-templates select="MeetingWorkBook/Meeting[4]/LAC/LACItem[2]">
                      <xsl:with-param name="strClass">borderLeftBottom</xsl:with-param>
                    </xsl:apply-templates>
                  </xsl:when>
                  <xsl:otherwise>
                    <xsl:apply-templates select="MeetingWorkBook/Meeting[4]/LAC/LACItem[2]">
                      <xsl:with-param name="strClass">borderLeftRightBottom</xsl:with-param>
                    </xsl:apply-templates>
                    <xsl:apply-templates select="MeetingWorkBook/Meeting[5]/LAC/LACItem[2]">
                      <xsl:with-param name="strClass">borderLeftBottom</xsl:with-param>
                    </xsl:apply-templates>
                  </xsl:otherwise>
                </xsl:choose>
              </tr>
            </xsl:if>

            <!-- Display the CBS Heading -->
            <xsl:call-template name="TopRowGap"/>
            <tr>
              <xsl:call-template name="EmptyLabelCell"/>
              <td colspan="4" class="cellCBS">
                <xsl:if test="count(MeetingWorkBook/Meeting) = 5">
                  <xsl:attribute name="colspan">5</xsl:attribute>
                </xsl:if>
                <xsl:value-of select="//Labels/CBS"/>
              </td>
            </tr>
            <xsl:call-template name="TopRowGap"/>

            <!-- Conductor -->
            <tr>
              <td class="cellLabel">
                <xsl:value-of select="$Translations/msa:Translations/msa:*[local-name() = $LangCode]/msa:Conductor"/>
              </td>
              <!-- Only display the Special Event information if:
                     1. It is an "All Day Event" (no meetings).
                     2. It is a "Midweek Memorial Event" (no midweek meeting) -->
              <!-- CircuitVisit / Conductor elements are only present in the data file if there is an actual "Midweek Meeting" for the week -->
              <xsl:apply-templates select="MeetingWorkBook/Meeting[1]/SpecialEvent[Date/@AllDayEvent='1' or (Date/@MidweekEvent='1' and Date/@Memorial='1')]/Event" mode="CBS">
                <xsl:with-param name="strClass">borderRight</xsl:with-param>
              </xsl:apply-templates>
              <xsl:apply-templates select="MeetingWorkBook/Meeting[1]/LAC/CircuitVisit" mode="CBS">
                <xsl:with-param name="strClass">cellCircuitVisit borderRight</xsl:with-param>
              </xsl:apply-templates>
              <xsl:apply-templates select="MeetingWorkBook/Meeting[1]/LAC/CongregationBibleStudy/Conductor" mode="CBS">
                <xsl:with-param name="strClass">borderRightBottom</xsl:with-param>
              </xsl:apply-templates>
              <xsl:apply-templates select="MeetingWorkBook/Meeting[2]/SpecialEvent[Date/@AllDayEvent='1' or (Date/@MidweekEvent='1' and Date/@Memorial='1')]/Event" mode="CBS">
                <xsl:with-param name="strClass">borderLeftRight</xsl:with-param>
              </xsl:apply-templates>
              <xsl:apply-templates select="MeetingWorkBook/Meeting[2]/LAC/CircuitVisit" mode="CBS">
                <xsl:with-param name="strClass">cellCircuitVisit borderLeftRight</xsl:with-param>
              </xsl:apply-templates>
              <xsl:apply-templates select="MeetingWorkBook/Meeting[2]/LAC/CongregationBibleStudy/Conductor" mode="CBS">
                <xsl:with-param name="strClass">borderLeftRightBottom</xsl:with-param>
              </xsl:apply-templates>
              <xsl:apply-templates select="MeetingWorkBook/Meeting[3]/SpecialEvent[Date/@AllDayEvent='1' or (Date/@MidweekEvent='1' and Date/@Memorial='1')]/Event" mode="CBS">
                <xsl:with-param name="strClass">borderLeftRight</xsl:with-param>
              </xsl:apply-templates>
              <xsl:apply-templates select="MeetingWorkBook/Meeting[3]/LAC/CircuitVisit" mode="CBS">
                <xsl:with-param name="strClass">cellCircuitVisit borderLeftRight</xsl:with-param>
              </xsl:apply-templates>
              <xsl:apply-templates select="MeetingWorkBook/Meeting[3]/LAC/CongregationBibleStudy/Conductor" mode="CBS">
                <xsl:with-param name="strClass">borderLeftRightBottom</xsl:with-param>
              </xsl:apply-templates>
              <xsl:choose>
                <xsl:when test="count(MeetingWorkBook/Meeting) = 4">
                  <xsl:apply-templates select="MeetingWorkBook/Meeting[4]/SpecialEvent[Date/@AllDayEvent='1' or (Date/@MidweekEvent='1' and Date/@Memorial='1')]/Event" mode="CBS">
                    <xsl:with-param name="strClass">borderLeft</xsl:with-param>
                  </xsl:apply-templates>
                  <xsl:apply-templates select="MeetingWorkBook/Meeting[4]/LAC/CircuitVisit" mode="CBS">
                    <xsl:with-param name="strClass">cellCircuitVisit borderLeft</xsl:with-param>
                  </xsl:apply-templates>
                  <xsl:apply-templates select="MeetingWorkBook/Meeting[4]/LAC/CongregationBibleStudy/Conductor" mode="CBS">
                    <xsl:with-param name="strClass">borderLeftBottom</xsl:with-param>
                  </xsl:apply-templates>
                </xsl:when>
                <xsl:otherwise>
                  <xsl:apply-templates select="MeetingWorkBook/Meeting[4]/SpecialEvent[Date/@AllDayEvent='1' or (Date/@MidweekEvent='1' and Date/@Memorial='1')]/Event" mode="CBS">
                    <xsl:with-param name="strClass">borderLeftRight</xsl:with-param>
                  </xsl:apply-templates>
                  <xsl:apply-templates select="MeetingWorkBook/Meeting[4]/LAC/CircuitVisit" mode="CBS">
                    <xsl:with-param name="strClass">cellCircuitVisit borderLeftRight</xsl:with-param>
                  </xsl:apply-templates>
                  <xsl:apply-templates select="MeetingWorkBook/Meeting[4]/LAC/CongregationBibleStudy/Conductor" mode="CBS">
                    <xsl:with-param name="strClass">borderLeftRightBottom</xsl:with-param>
                  </xsl:apply-templates>
                  <xsl:apply-templates select="MeetingWorkBook/Meeting[5]/SpecialEvent[Date/@AllDayEvent='1' or (Date/@MidweekEvent='1' and Date/@Memorial='1')]/Event" mode="CBS">
                    <xsl:with-param name="strClass">borderLeft</xsl:with-param>
                  </xsl:apply-templates>
                  <xsl:apply-templates select="MeetingWorkBook/Meeting[5]/LAC/CircuitVisit" mode="CBS">
                    <xsl:with-param name="strClass">cellCircuitVisit borderLeft</xsl:with-param>
                  </xsl:apply-templates>
                  <xsl:apply-templates select="MeetingWorkBook/Meeting[5]/LAC/CongregationBibleStudy/Conductor" mode="CBS">
                    <xsl:with-param name="strClass">borderLeftBottom</xsl:with-param>
                  </xsl:apply-templates>
                </xsl:otherwise>
              </xsl:choose>
            </tr>

            <!-- Reader -->
            <tr>
              <td class="cellLabel">
                <xsl:value-of select="$Translations/msa:Translations/msa:*[local-name() = $LangCode]/msa:Reader"/>
              </td>
              <!--The templates will only be applied if the specified nodes exist in the XML document.
              So there is no need to use multiple IF checks.-->
              <xsl:apply-templates select="MeetingWorkBook/Meeting[1]/LAC/CongregationBibleStudy/Reader" mode="CBS">
                <xsl:with-param name="strClass">borderRight</xsl:with-param>
              </xsl:apply-templates>
              <xsl:apply-templates select="MeetingWorkBook/Meeting[2]/LAC/CongregationBibleStudy/Reader" mode="CBS">
                <xsl:with-param name="strClass">borderLeftRight</xsl:with-param>
              </xsl:apply-templates>
              <xsl:apply-templates select="MeetingWorkBook/Meeting[3]/LAC/CongregationBibleStudy/Reader" mode="CBS">
                <xsl:with-param name="strClass">borderLeftRight</xsl:with-param>
              </xsl:apply-templates>
              <xsl:choose>
                <xsl:when test="count(MeetingWorkBook/Meeting) = 4">
                  <xsl:apply-templates select="MeetingWorkBook/Meeting[4]/LAC/CongregationBibleStudy/Reader" mode="CBS">
                    <xsl:with-param name="strClass">borderLeft</xsl:with-param>
                  </xsl:apply-templates>
                </xsl:when>
                <xsl:otherwise>
                  <xsl:apply-templates select="MeetingWorkBook/Meeting[4]/LAC/CongregationBibleStudy/Reader" mode="CBS">
                    <xsl:with-param name="strClass">borderLeftRight</xsl:with-param>
                  </xsl:apply-templates>
                  <xsl:apply-templates select="MeetingWorkBook/Meeting[5]/LAC/CongregationBibleStudy/Reader" mode="CBS">
                    <xsl:with-param name="strClass">borderLeft</xsl:with-param>
                  </xsl:apply-templates>
                </xsl:otherwise>
              </xsl:choose>
            </tr>

            <!-- Insert row of assigned Prayer(or the Special Event description) -->
            <xsl:call-template name="TopRowGap"/>
            <tr>
              <td class="cellLabel">
                <xsl:value-of select="$Translations/msa:Translations/msa:*[local-name() = $LangCode]/msa:Prayer"/>
              </td>
              <xsl:apply-templates select="MeetingWorkBook/Meeting[1]/LAC/PrayerEnd" mode="OtherRow">
                <xsl:with-param name="strClass">borderRight</xsl:with-param>
              </xsl:apply-templates>
              <xsl:apply-templates select="MeetingWorkBook/Meeting[2]/LAC/PrayerEnd" mode="OtherRow">
                <xsl:with-param name="strClass">borderLeftRight</xsl:with-param>
              </xsl:apply-templates>
              <xsl:apply-templates select="MeetingWorkBook/Meeting[3]/LAC/PrayerEnd" mode="OtherRow">
                <xsl:with-param name="strClass">borderLeftRight</xsl:with-param>
              </xsl:apply-templates>
              <xsl:choose>
                <xsl:when test="count(MeetingWorkBook/Meeting) = 4">
                  <xsl:apply-templates select="MeetingWorkBook/Meeting[4]/LAC/PrayerEnd" mode="OtherRow">
                    <xsl:with-param name="strClass">borderLeft</xsl:with-param>
                  </xsl:apply-templates>
                </xsl:when>
                <xsl:otherwise>
                  <xsl:apply-templates select="MeetingWorkBook/Meeting[4]/LAC/PrayerEnd" mode="OtherRow">
                    <xsl:with-param name="strClass">borderLeftRight</xsl:with-param>
                  </xsl:apply-templates>
                  <xsl:apply-templates select="MeetingWorkBook/Meeting[5]/LAC/PrayerEnd" mode="OtherRow">
                    <xsl:with-param name="strClass">borderLeft</xsl:with-param>
                  </xsl:apply-templates>
                </xsl:otherwise>
              </xsl:choose>
            </tr>
          </table>
          <hr/>
          <table cellpadding="0" cellspacing="0"  class="tableSchedule">
            <xsl:call-template name="SetColumnWidths"/>

            <!-- Public Talk Date -->
            <tr>
              <xsl:call-template name="EmptyLabelCell"/>
              <!-- Only display the Special Event information if:
                     1. It is an "All Day Event" (no meetings).
                     2. It is a "Weekend Memorial Event" (no weekend meeting) -->
              <!-- MeetingDate elements are only present in the data file if there is an actual "Weekend Meeting" for the week -->
              <xsl:apply-templates select="MeetingWorkBook/Meeting[1]/SpecialEvent/Date[@AllDayEvent='1' or (@MidweekEvent='0' and @Memorial='1')]"/>
              <xsl:apply-templates select="MeetingWorkBook/Meeting[1]/PUBLICTALK/MeetingDate"/>
              <xsl:apply-templates select="MeetingWorkBook/Meeting[2]/SpecialEvent/Date[@AllDayEvent='1' or (@MidweekEvent='0' and @Memorial='1')]"/>
              <xsl:apply-templates select="MeetingWorkBook/Meeting[2]/PUBLICTALK/MeetingDate"/>
              <xsl:apply-templates select="MeetingWorkBook/Meeting[3]/SpecialEvent/Date[@AllDayEvent='1' or (@MidweekEvent='0' and @Memorial='1')]"/>
              <xsl:apply-templates select="MeetingWorkBook/Meeting[3]/PUBLICTALK/MeetingDate"/>
              <xsl:apply-templates select="MeetingWorkBook/Meeting[4]/SpecialEvent/Date[@AllDayEvent='1' or (@MidweekEvent='0' and @Memorial='1')]"/>
              <xsl:apply-templates select="MeetingWorkBook/Meeting[4]/PUBLICTALK/MeetingDate"/>
              <xsl:apply-templates select="MeetingWorkBook/Meeting[5]/SpecialEvent/Date[@AllDayEvent='1' or (@MidweekEvent='0' and @Memorial='1')]"/>
              <xsl:apply-templates select="MeetingWorkBook/Meeting[5]/PUBLICTALK/MeetingDate"/>
            </tr>

            <!-- Heading -->
            <xsl:call-template name="Heading">
              <xsl:with-param name="strTitle">
                <xsl:value-of select="$Translations/msa:Translations/msa:*[local-name() = $LangCode]/msa:PublicTalk"/>
              </xsl:with-param>
              <xsl:with-param name="strClass">cellWEEKEND</xsl:with-param>
            </xsl:call-template>

            <!-- Theme -->
            <tr>
              <td class="cellLabel">
                <xsl:value-of select="$Translations/msa:Translations/msa:*[local-name() = $LangCode]/msa:Theme"/>
              </td>
              <!-- Only display the Special Event information if:
                     1. It is an "All Day Event" (no meetings).
                     2. It is a "Weekend Memorial Event" (no weekend meeting) -->
              <!-- HomeTalk elements are only present in the data file if there is an actual "Weekend Meeting" for the week -->
              <xsl:apply-templates select="MeetingWorkBook/Meeting[1]/SpecialEvent[Date/@AllDayEvent='1' or (Date/@MidweekEvent='0' and Date/@Memorial='1')]/Event" mode="Weekend">
                <xsl:with-param name="strClass">borderRight</xsl:with-param>
              </xsl:apply-templates>
              <xsl:apply-templates select="MeetingWorkBook/Meeting[1]/PUBLICTALK/HomeTalk/Theme" mode="Weekend">
                <xsl:with-param name="strClass">borderRightBottom</xsl:with-param>
              </xsl:apply-templates>
              <xsl:apply-templates select="MeetingWorkBook/Meeting[2]/SpecialEvent[Date/@AllDayEvent='1' or (Date/@MidweekEvent='0' and Date/@Memorial='1')]/Event" mode="Weekend">
                <xsl:with-param name="strClass">borderLeftRight</xsl:with-param>
              </xsl:apply-templates>
              <xsl:apply-templates select="MeetingWorkBook/Meeting[2]/PUBLICTALK/HomeTalk/Theme" mode="Weekend">
                <xsl:with-param name="strClass">borderLeftRightBottom</xsl:with-param>
              </xsl:apply-templates>
              <xsl:apply-templates select="MeetingWorkBook/Meeting[3]/SpecialEvent[Date/@AllDayEvent='1' or (Date/@MidweekEvent='0' and Date/@Memorial='1')]/Event" mode="Weekend">
                <xsl:with-param name="strClass">borderLeftRight</xsl:with-param>
              </xsl:apply-templates>
              <xsl:apply-templates select="MeetingWorkBook/Meeting[3]/PUBLICTALK/HomeTalk/Theme" mode="Weekend">
                <xsl:with-param name="strClass">borderLeftRightBottom</xsl:with-param>
              </xsl:apply-templates>
              <xsl:choose>
                <xsl:when test="count(MeetingWorkBook/Meeting) = 4">
                  <xsl:apply-templates select="MeetingWorkBook/Meeting[4]/SpecialEvent[Date/@AllDayEvent='1' or (Date/@MidweekEvent='0' and Date/@Memorial='1')]/Event" mode="Weekend">
                    <xsl:with-param name="strClass">borderLeft</xsl:with-param>
                  </xsl:apply-templates>
                  <xsl:apply-templates select="MeetingWorkBook/Meeting[4]/PUBLICTALK/HomeTalk/Theme" mode="Weekend">
                    <xsl:with-param name="strClass">borderLeftBottom</xsl:with-param>
                  </xsl:apply-templates>
                </xsl:when>
                <xsl:otherwise>
                  <xsl:apply-templates select="MeetingWorkBook/Meeting[4]/SpecialEvent[Date/@AllDayEvent='1' or (Date/@MidweekEvent='0' and Date/@Memorial='1')]/Event" mode="Weekend">
                    <xsl:with-param name="strClass">borderLeftRight</xsl:with-param>
                  </xsl:apply-templates>
                  <xsl:apply-templates select="MeetingWorkBook/Meeting[4]/PUBLICTALK/HomeTalk/Theme" mode="Weekend">
                    <xsl:with-param name="strClass">borderLeftRightBottom</xsl:with-param>
                  </xsl:apply-templates>
                  <xsl:apply-templates select="MeetingWorkBook/Meeting[5]/SpecialEvent[Date/@AllDayEvent='1' or (Date/@MidweekEvent='0' and Date/@Memorial='1')]/Event" mode="Weekend">
                    <xsl:with-param name="strClass">borderLeft</xsl:with-param>
                  </xsl:apply-templates>
                  <xsl:apply-templates select="MeetingWorkBook/Meeting[5]/PUBLICTALK/HomeTalk/Theme" mode="Weekend">
                    <xsl:with-param name="strClass">borderLeftBottom</xsl:with-param>
                  </xsl:apply-templates>
                </xsl:otherwise>
              </xsl:choose>
            </tr>

            <!-- Speaker -->
            <tr>
              <td class="cellLabel">
                <xsl:value-of select="$Translations/msa:Translations/msa:*[local-name() = $LangCode]/msa:Speaker"/>
              </td>
              <!--The templates will only be applied if the specified nodes exist in the XML document.
              So there is no need to use multiple IF checks.-->
              <xsl:apply-templates select="MeetingWorkBook/Meeting[1]/PUBLICTALK/HomeTalk/Speaker" mode="Weekend">
                <xsl:with-param name="strClass">borderRightBottom</xsl:with-param>
              </xsl:apply-templates>
              <xsl:apply-templates select="MeetingWorkBook/Meeting[2]/PUBLICTALK/HomeTalk/Speaker" mode="Weekend">
                <xsl:with-param name="strClass">borderLeftRightBottom</xsl:with-param>
              </xsl:apply-templates>
              <xsl:apply-templates select="MeetingWorkBook/Meeting[3]/PUBLICTALK/HomeTalk/Speaker" mode="Weekend">
                <xsl:with-param name="strClass">borderLeftRightBottom</xsl:with-param>
              </xsl:apply-templates>
              <xsl:choose>
                <xsl:when test="count(MeetingWorkBook/Meeting) = 4">
                  <xsl:apply-templates select="MeetingWorkBook/Meeting[4]/PUBLICTALK/HomeTalk/Speaker" mode="Weekend">
                    <xsl:with-param name="strClass">borderLeftBottom</xsl:with-param>
                  </xsl:apply-templates>
                </xsl:when>
                <xsl:otherwise>
                  <xsl:apply-templates select="MeetingWorkBook/Meeting[4]/PUBLICTALK/HomeTalk/Speaker" mode="Weekend">
                    <xsl:with-param name="strClass">borderLeftRightBottom</xsl:with-param>
                  </xsl:apply-templates>
                  <xsl:apply-templates select="MeetingWorkBook/Meeting[5]/PUBLICTALK/HomeTalk/Speaker" mode="Weekend">
                    <xsl:with-param name="strClass">borderLeftBottom</xsl:with-param>
                  </xsl:apply-templates>
                </xsl:otherwise>
              </xsl:choose>
            </tr>

            <!-- Chairman -->
            <tr>
              <td class="cellLabel">
                <xsl:value-of select="$Translations/msa:Translations/msa:*[local-name() = $LangCode]/msa:Chairman"/>
              </td>
              <!--The templates will only be applied if the specified nodes exist in the XML document.
              So there is no need to use multiple IF checks.-->
              <xsl:apply-templates select="MeetingWorkBook/Meeting[1]/PUBLICTALK/Assignments/Chairman" mode="Weekend">
                <xsl:with-param name="strClass">borderRight</xsl:with-param>
              </xsl:apply-templates>
              <xsl:apply-templates select="MeetingWorkBook/Meeting[2]/PUBLICTALK/Assignments/Chairman" mode="Weekend">
                <xsl:with-param name="strClass">borderLeftRight</xsl:with-param>
              </xsl:apply-templates>
              <xsl:apply-templates select="MeetingWorkBook/Meeting[3]/PUBLICTALK/Assignments/Chairman" mode="Weekend">
                <xsl:with-param name="strClass">borderLeftRight</xsl:with-param>
              </xsl:apply-templates>
              <xsl:choose>
                <xsl:when test="count(MeetingWorkBook/Meeting) = 4">
                  <xsl:apply-templates select="MeetingWorkBook/Meeting[4]/PUBLICTALK/Assignments/Chairman" mode="Weekend">
                    <xsl:with-param name="strClass">borderLeft</xsl:with-param>
                  </xsl:apply-templates>
                </xsl:when>
                <xsl:otherwise>
                  <xsl:apply-templates select="MeetingWorkBook/Meeting[4]/PUBLICTALK/Assignments/Chairman" mode="Weekend">
                    <xsl:with-param name="strClass">borderLeftRight</xsl:with-param>
                  </xsl:apply-templates>
                  <xsl:apply-templates select="MeetingWorkBook/Meeting[5]/PUBLICTALK/Assignments/Chairman" mode="Weekend">
                    <xsl:with-param name="strClass">borderLeft</xsl:with-param>
                  </xsl:apply-templates>
                </xsl:otherwise>
              </xsl:choose>
            </tr>

            <!-- Heading -->
            <xsl:call-template name="Heading">
              <xsl:with-param name="strTitle">
                <xsl:value-of select="$Translations/msa:Translations/msa:*[local-name() = $LangCode]/msa:WTStudy"/>
              </xsl:with-param>
              <xsl:with-param name="strClass">cellWEEKEND</xsl:with-param>
            </xsl:call-template>

            <!-- Theme -->
            <tr>
              <td class="cellLabel">
                <xsl:value-of select="$Translations/msa:Translations/msa:*[local-name() = $LangCode]/msa:Theme"/>
              </td>
              <!-- Only display the Special Event information if:
                     1. It is an "All Day Event" (no meetings).
                     2. It is a "Weekend Memorial Event" (no weekend meeting) -->
              <!-- WatchtowerStudy elements are only present in the data file if there is an actual "Weekend Meeting" for the week -->
              <xsl:apply-templates select="MeetingWorkBook/Meeting[1]/SpecialEvent[Date/@AllDayEvent='1' or (Date/@MidweekEvent='0' and Date/@Memorial='1')]/Event" mode="WatchtowerStudy">
                <xsl:with-param name="strClass">cellBold borderRight</xsl:with-param>
              </xsl:apply-templates>
              <xsl:apply-templates select="MeetingWorkBook/Meeting[1]/PUBLICTALK/Assignments/WatchtowerStudy/Theme" mode="WatchtowerStudy">
                <xsl:with-param name="strClass">borderRight</xsl:with-param>
              </xsl:apply-templates>
              <xsl:apply-templates select="MeetingWorkBook/Meeting[2]/SpecialEvent[Date/@AllDayEvent='1' or (Date/@MidweekEvent='0' and Date/@Memorial='1')]/Event" mode="WatchtowerStudy">
                <xsl:with-param name="strClass">cellBold borderLeftRight</xsl:with-param>
              </xsl:apply-templates>
              <xsl:apply-templates select="MeetingWorkBook/Meeting[2]/PUBLICTALK/Assignments/WatchtowerStudy/Theme" mode="WatchtowerStudy">
                <xsl:with-param name="strClass">borderLeftRight</xsl:with-param>
              </xsl:apply-templates>
              <xsl:apply-templates select="MeetingWorkBook/Meeting[3]/SpecialEvent[Date/@AllDayEvent='1' or (Date/@MidweekEvent='0' and Date/@Memorial='1')]/Event" mode="WatchtowerStudy">
                <xsl:with-param name="strClass">cellBold borderLeftRight</xsl:with-param>
              </xsl:apply-templates>
              <xsl:apply-templates select="MeetingWorkBook/Meeting[3]/PUBLICTALK/Assignments/WatchtowerStudy/Theme" mode="WatchtowerStudy">
                <xsl:with-param name="strClass">borderLeftRight</xsl:with-param>
              </xsl:apply-templates>
              <xsl:choose>
                <xsl:when test="count(MeetingWorkBook/Meeting) = 4">
                  <xsl:apply-templates select="MeetingWorkBook/Meeting[4]/SpecialEvent[Date/@AllDayEvent='1' or (Date/@MidweekEvent='0' and Date/@Memorial='1')]/Event" mode="WatchtowerStudy">
                    <xsl:with-param name="strClass">cellBold borderLeft</xsl:with-param>
                  </xsl:apply-templates>
                  <xsl:apply-templates select="MeetingWorkBook/Meeting[4]/PUBLICTALK/Assignments/WatchtowerStudy/Theme" mode="WatchtowerStudy">
                    <xsl:with-param name="strClass">borderLeft</xsl:with-param>
                  </xsl:apply-templates>
                </xsl:when>
                <xsl:otherwise>
                  <xsl:apply-templates select="MeetingWorkBook/Meeting[4]/SpecialEvent[Date/@AllDayEvent='1' or (Date/@MidweekEvent='0' and Date/@Memorial='1')]/Event" mode="WatchtowerStudy">
                    <xsl:with-param name="strClass">cellBold borderLeftRight</xsl:with-param>
                  </xsl:apply-templates>
                  <xsl:apply-templates select="MeetingWorkBook/Meeting[4]/PUBLICTALK/Assignments/WatchtowerStudy/Theme" mode="WatchtowerStudy">
                    <xsl:with-param name="strClass">borderLeftRight</xsl:with-param>
                  </xsl:apply-templates>
                  <xsl:apply-templates select="MeetingWorkBook/Meeting[5]/SpecialEvent[Date/@AllDayEvent='1' or (Date/@MidweekEvent='0' and Date/@Memorial='1')]/Event" mode="WatchtowerStudy">
                    <xsl:with-param name="strClass">cellBold borderLeft</xsl:with-param>
                  </xsl:apply-templates>
                  <xsl:apply-templates select="MeetingWorkBook/Meeting[5]/PUBLICTALK/Assignments/WatchtowerStudy/Theme" mode="WatchtowerStudy">
                    <xsl:with-param name="strClass">borderLeft</xsl:with-param>
                  </xsl:apply-templates>
                </xsl:otherwise>
              </xsl:choose>
            </tr>

            <!-- Conductor -->
            <tr>
              <td class="cellLabel">
                <xsl:value-of select="$Translations/msa:Translations/msa:*[local-name() = $LangCode]/msa:Conductor"/>
              </td>
              <!--The templates will only be applied if the specified nodes exist in the XML document.
              So there is no need to use multiple IF checks.-->
              <xsl:apply-templates select="MeetingWorkBook/Meeting[1]/PUBLICTALK/Assignments/Conductor" mode="WatchtowerStudy">
                <xsl:with-param name="strClass">cellBold borderRightBottom</xsl:with-param>
              </xsl:apply-templates>
              <xsl:apply-templates select="MeetingWorkBook/Meeting[2]/PUBLICTALK/Assignments/Conductor" mode="WatchtowerStudy">
                <xsl:with-param name="strClass">cellBold borderLeftRightBottom</xsl:with-param>
              </xsl:apply-templates>
              <xsl:apply-templates select="MeetingWorkBook/Meeting[3]/PUBLICTALK/Assignments/Conductor" mode="WatchtowerStudy">
                <xsl:with-param name="strClass">cellBold borderRightBottom</xsl:with-param>
              </xsl:apply-templates>
              <xsl:choose>
                <xsl:when test="count(MeetingWorkBook/Meeting) = 4">
                  <xsl:apply-templates select="MeetingWorkBook/Meeting[4]/PUBLICTALK/Assignments/Conductor" mode="WatchtowerStudy">
                    <xsl:with-param name="strClass">cellBold borderLeftBottom</xsl:with-param>
                  </xsl:apply-templates>
                </xsl:when>
                <xsl:otherwise>
                  <xsl:apply-templates select="MeetingWorkBook/Meeting[4]/PUBLICTALK/Assignments/Conductor" mode="WatchtowerStudy">
                    <xsl:with-param name="strClass">cellBold borderLeftRightBottom</xsl:with-param>
                  </xsl:apply-templates>
                  <xsl:apply-templates select="MeetingWorkBook/Meeting[5]/PUBLICTALK/Assignments/Conductor" mode="WatchtowerStudy">
                    <xsl:with-param name="strClass">cellBold borderLeftBottom</xsl:with-param>
                  </xsl:apply-templates>
                </xsl:otherwise>
              </xsl:choose>
            </tr>

            <!-- Reader / Service Talk (if Circuit Visit) -->
            <tr>
              <td class="cellLabel">
                <xsl:value-of select="$Translations/msa:Translations/msa:*[local-name() = $LangCode]/msa:Reader"/>
              </td>
              <xsl:apply-templates select="MeetingWorkBook/Meeting[1]/PUBLICTALK/Assignments/ServiceTalk" mode="WatchtowerStudy">
                <xsl:with-param name="strClass">cellBold cellCircuitVisit borderRight</xsl:with-param>
              </xsl:apply-templates>
              <xsl:if test ="MeetingWorkBook/Meeting[1]/SpecialEvent/Date/@MidweekEvent='1' or MeetingWorkBook/Meeting[1]/@CircuitVisit='0'">
                <xsl:apply-templates select="MeetingWorkBook/Meeting[1]/PUBLICTALK/Assignments/Reader" mode="WatchtowerStudy">
                  <xsl:with-param name="strClass">cellBold borderRight</xsl:with-param>
                </xsl:apply-templates>
              </xsl:if>
              <xsl:apply-templates select="MeetingWorkBook/Meeting[2]/PUBLICTALK/Assignments/ServiceTalk" mode="WatchtowerStudy">
                <xsl:with-param name="strClass">cellBold cellCircuitVisit borderLeftRight</xsl:with-param>
              </xsl:apply-templates>
              <xsl:if test ="MeetingWorkBook/Meeting[2]/SpecialEvent/Date/@MidweekEvent='1' or MeetingWorkBook/Meeting[2]/@CircuitVisit='0'">
                <xsl:apply-templates select="MeetingWorkBook/Meeting[2]/PUBLICTALK/Assignments/Reader" mode="WatchtowerStudy">
                  <xsl:with-param name="strClass">cellBold borderLeftRight</xsl:with-param>
                </xsl:apply-templates>
              </xsl:if>
              <xsl:apply-templates select="MeetingWorkBook/Meeting[3]/PUBLICTALK/Assignments/ServiceTalk" mode="WatchtowerStudy">
                <xsl:with-param name="strClass">cellBold cellCircuitVisit borderLeftRight</xsl:with-param>
              </xsl:apply-templates>
              <xsl:if test ="MeetingWorkBook/Meeting[3]/SpecialEvent/Date/@MidweekEvent='1' or MeetingWorkBook/Meeting[3]/@CircuitVisit='0'">
                <xsl:apply-templates select="MeetingWorkBook/Meeting[3]/PUBLICTALK/Assignments/Reader" mode="WatchtowerStudy">
                  <xsl:with-param name="strClass">cellBold borderRight</xsl:with-param>
                </xsl:apply-templates>
              </xsl:if>
              <xsl:choose>
                <xsl:when test="count(MeetingWorkBook/Meeting) = 4">
                  <xsl:apply-templates select="MeetingWorkBook/Meeting[4]/PUBLICTALK/Assignments/ServiceTalk" mode="WatchtowerStudy">
                    <xsl:with-param name="strClass">cellBold cellCircuitVisit borderLeft</xsl:with-param>
                  </xsl:apply-templates>
                  <xsl:if test ="MeetingWorkBook/Meeting[4]/SpecialEvent/Date/@MidweekEvent='1' or MeetingWorkBook/Meeting[4]/@CircuitVisit='0'">
                    <xsl:apply-templates select="MeetingWorkBook/Meeting[4]/PUBLICTALK/Assignments/Reader" mode="WatchtowerStudy">
                      <xsl:with-param name="strClass">cellBold borderLeft</xsl:with-param>
                    </xsl:apply-templates>
                  </xsl:if>
                </xsl:when>
                <xsl:otherwise>
                  <xsl:apply-templates select="MeetingWorkBook/Meeting[4]/PUBLICTALK/Assignments/ServiceTalk" mode="WatchtowerStudy">
                    <xsl:with-param name="strClass">cellBold cellCircuitVisit borderLeftRight</xsl:with-param>
                  </xsl:apply-templates>
                  <xsl:if test ="MeetingWorkBook/Meeting[4]/SpecialEvent/Date/@MidweekEvent='1' or MeetingWorkBook/Meeting[4]/@CircuitVisit='0'">
                    <xsl:apply-templates select="MeetingWorkBook/Meeting[4]/PUBLICTALK/Assignments/Reader" mode="WatchtowerStudy">
                      <xsl:with-param name="strClass">cellBold borderLeftRight</xsl:with-param>
                    </xsl:apply-templates>
                  </xsl:if>
                  <xsl:apply-templates select="MeetingWorkBook/Meeting[5]/PUBLICTALK/Assignments/ServiceTalk" mode="WatchtowerStudy">
                    <xsl:with-param name="strClass">cellBold cellCircuitVisit borderLeft</xsl:with-param>
                  </xsl:apply-templates>
                  <xsl:if test ="MeetingWorkBook/Meeting[5]/SpecialEvent/Date/@MidweekEvent='1' or MeetingWorkBook/Meeting[5]/@CircuitVisit='0'">
                    <xsl:apply-templates select="MeetingWorkBook/Meeting[5]/PUBLICTALK/Assignments/Reader" mode="WatchtowerStudy">
                      <xsl:with-param name="strClass">cellBold borderLeft</xsl:with-param>
                    </xsl:apply-templates>
                  </xsl:if>
                </xsl:otherwise>
              </xsl:choose>
            </tr>

            <!-- Hospitality -->
            <tr>
              <td class="cellLabel">
                <xsl:value-of select="$Translations/msa:Translations/msa:*[local-name() = $LangCode]/msa:Hospitality"/>
              </td>
              <!--The templates will only be applied if the specified nodes exist in the XML document.
              So there is no need to use multiple IF checks.-->
              <xsl:apply-templates select="MeetingWorkBook/Meeting[1]/PUBLICTALK/Assignments/Hospitality" mode="WatchtowerStudy">
                <xsl:with-param name="strClass">cellBold borderRight</xsl:with-param>
              </xsl:apply-templates>
              <xsl:apply-templates select="MeetingWorkBook/Meeting[2]/PUBLICTALK/Assignments/Hospitality" mode="WatchtowerStudy">
                <xsl:with-param name="strClass">cellBold borderRight</xsl:with-param>
              </xsl:apply-templates>
              <xsl:apply-templates select="MeetingWorkBook/Meeting[3]/PUBLICTALK/Assignments/Hospitality" mode="WatchtowerStudy">
                <xsl:with-param name="strClass">cellBold borderRight</xsl:with-param>
              </xsl:apply-templates>
              <xsl:choose>
                <xsl:when test="count(MeetingWorkBook/Meeting) = 4">
                  <xsl:apply-templates select="MeetingWorkBook/Meeting[4]/PUBLICTALK/Assignments/Hospitality" mode="WatchtowerStudy">
                    <xsl:with-param name="strClass">cellBold borderLeft</xsl:with-param>
                  </xsl:apply-templates>
                </xsl:when>
                <xsl:otherwise>
                  <xsl:apply-templates select="MeetingWorkBook/Meeting[4]/PUBLICTALK/Assignments/Hospitality" mode="WatchtowerStudy">
                    <xsl:with-param name="strClass">cellBold borderLeftRight</xsl:with-param>
                  </xsl:apply-templates>
                  <xsl:apply-templates select="MeetingWorkBook/Meeting[5]/PUBLICTALK/Assignments/Hospitality" mode="WatchtowerStudy">
                    <xsl:with-param name="strClass">cellBold borderLeft</xsl:with-param>
                  </xsl:apply-templates>
                </xsl:otherwise>
              </xsl:choose>
            </tr>

            <!--Assignments-->
            <xsl:call-template name="Heading">
              <xsl:with-param name="strTitle">
                <xsl:value-of select="$Translations/msa:Translations/msa:*[local-name() = $LangCode]/msa:Assignments"/>
              </xsl:with-param>
              <xsl:with-param name="strClass">cellOtherHeading</xsl:with-param>
            </xsl:call-template>
            <xsl:variable name="Week1" select="MeetingWorkBook/Meeting[1]/Date/@ThisWeek"/>
            <xsl:variable name="Week2" select="MeetingWorkBook/Meeting[2]/Date/@ThisWeek"/>
            <xsl:variable name="Week3" select="MeetingWorkBook/Meeting[3]/Date/@ThisWeek"/>
            <xsl:variable name="Week4" select="MeetingWorkBook/Meeting[4]/Date/@ThisWeek"/>
            <xsl:variable name="Week5" select="MeetingWorkBook/Meeting[5]/Date/@ThisWeek"/>

            <xsl:variable name="Weekend-Assignments1"
                               select="$DutyHistory/msa:DutyAssignmentHistory/msa:DutyAssignments
                          /msa:DutyAssignmentEntry[@Week=$Week1 and @Mode='Weekly']/msa:Assignment"/>
            <xsl:variable name="Weekend-Assignments2"
                           select="$DutyHistory/msa:DutyAssignmentHistory/msa:DutyAssignments
                          /msa:DutyAssignmentEntry[@Week=$Week2 and @Mode='Weekly']/msa:Assignment"/>
            <xsl:variable name="Weekend-Assignments3"
                           select="$DutyHistory/msa:DutyAssignmentHistory/msa:DutyAssignments
                          /msa:DutyAssignmentEntry[@Week=$Week3 and @Mode='Weekly']/msa:Assignment"/>
            <xsl:variable name="Weekend-Assignments4"
                           select="$DutyHistory/msa:DutyAssignmentHistory/msa:DutyAssignments
                          /msa:DutyAssignmentEntry[@Week=$Week4 and @Mode='Weekly']/msa:Assignment"/>
            <xsl:variable name="Weekend-Assignments5"
                           select="$DutyHistory/msa:DutyAssignmentHistory/msa:DutyAssignments
                          /msa:DutyAssignmentEntry[@Week=$Week5 and @Mode='Weekly']/msa:Assignment"/>
            <!--Sound-->
            <tr>
              <td class="cellLabel">Sound</td>
              <xsl:apply-templates select="MeetingWorkBook/Meeting[1]/SpecialEvent/Event" mode="Assignment">
                <xsl:with-param name="strClass">borderRight</xsl:with-param>
              </xsl:apply-templates>
              <xsl:apply-templates select="$Weekend-Assignments1[@Index='1' and @IndexType='Fixed']">
                <xsl:with-param name="strClass">borderRightBottom</xsl:with-param>
              </xsl:apply-templates>
              <xsl:apply-templates select="MeetingWorkBook/Meeting[2]/SpecialEvent/Event" mode="Assignment">
                <xsl:with-param name="strClass">borderLeftRight</xsl:with-param>
              </xsl:apply-templates>
              <xsl:apply-templates select="$Weekend-Assignments2[@Index='1' and @IndexType='Fixed']">
                <xsl:with-param name="strClass">borderLeftRightBottom</xsl:with-param>
              </xsl:apply-templates>
              <xsl:apply-templates select="MeetingWorkBook/Meeting[3]/SpecialEvent/Event" mode="Assignment">
                <xsl:with-param name="strClass">borderLeftRight</xsl:with-param>
              </xsl:apply-templates>
              <xsl:apply-templates select="$Weekend-Assignments3[@Index='1' and @IndexType='Fixed']">
                <xsl:with-param name="strClass">borderLeftRightBottom</xsl:with-param>
              </xsl:apply-templates>
              <xsl:choose>
                <xsl:when test="count(MeetingWorkBook/Meeting) = 4">
                  <xsl:apply-templates select="MeetingWorkBook/Meeting[4]/SpecialEvent/Event" mode="Assignment">
                    <xsl:with-param name="strClass">borderLeft</xsl:with-param>
                  </xsl:apply-templates>
                  <xsl:apply-templates select="$Weekend-Assignments4[@Index='1' and @IndexType='Fixed']">
                    <xsl:with-param name="strClass">borderLeftBottom</xsl:with-param>
                  </xsl:apply-templates>
                </xsl:when>
                <xsl:otherwise>
                  <xsl:apply-templates select="MeetingWorkBook/Meeting[4]/SpecialEvent/Event" mode="Assignment">
                    <xsl:with-param name="strClass">borderLeftRight</xsl:with-param>
                  </xsl:apply-templates>
                  <xsl:apply-templates select="$Weekend-Assignments4[@Index='1' and @IndexType='Fixed']">
                    <xsl:with-param name="strClass">borderLeftRightBottom</xsl:with-param>
                  </xsl:apply-templates>
                  <xsl:apply-templates select="MeetingWorkBook/Meeting[5]/SpecialEvent/Event" mode="Assignment">
                    <xsl:with-param name="strClass">borderLeft</xsl:with-param>
                  </xsl:apply-templates>
                  <xsl:apply-templates select="$Weekend-Assignments5[@Index='1' and @IndexType='Fixed']">
                    <xsl:with-param name="strClass">borderLeftBottom</xsl:with-param>
                  </xsl:apply-templates>
                </xsl:otherwise>
              </xsl:choose>
            </tr>
            <!--Platform-->
            <tr>
              <td class="cellLabel">Platform</td>
              <xsl:apply-templates select="$Weekend-Assignments1[@Index='5' and @IndexType='Fixed']">
                <xsl:with-param name="strClass">borderRightBottom</xsl:with-param>
              </xsl:apply-templates>
              <xsl:apply-templates select="$Weekend-Assignments2[@Index='5' and @IndexType='Fixed']">
                <xsl:with-param name="strClass">borderLeftRightBottom</xsl:with-param>
              </xsl:apply-templates>
              <xsl:apply-templates select="$Weekend-Assignments3[@Index='5' and @IndexType='Fixed']">
                <xsl:with-param name="strClass">borderLeftRightBottom</xsl:with-param>
              </xsl:apply-templates>
              <xsl:choose>
                <xsl:when test="count(MeetingWorkBook/Meeting) = 4">
                  <xsl:apply-templates select="$Weekend-Assignments4[@Index='5' and @IndexType='Fixed']">
                    <xsl:with-param name="strClass">borderLeftBottom</xsl:with-param>
                  </xsl:apply-templates>
                </xsl:when>
                <xsl:otherwise>
                  <xsl:apply-templates select="$Weekend-Assignments4[@Index='5' and @IndexType='Fixed']">
                    <xsl:with-param name="strClass">borderLeftRightBottom</xsl:with-param>
                  </xsl:apply-templates>
                  <xsl:apply-templates select="$Weekend-Assignments5[@Index='5' and @IndexType='Fixed']">
                    <xsl:with-param name="strClass">borderLeftBottom</xsl:with-param>
                  </xsl:apply-templates>
                </xsl:otherwise>
              </xsl:choose>
            </tr>
            <!--Microphone-->
            <tr>
              <td class="cellLabel">Mike</td>
              <xsl:apply-templates select="$Weekend-Assignments1[@Index='7' and @IndexType='Fixed']">
                <xsl:with-param name="strClass">borderRight</xsl:with-param>
              </xsl:apply-templates>
              <xsl:apply-templates select="$Weekend-Assignments2[@Index='7' and @IndexType='Fixed']">
                <xsl:with-param name="strClass">borderLeftRight</xsl:with-param>
              </xsl:apply-templates>
              <xsl:apply-templates select="$Weekend-Assignments3[@Index='7' and @IndexType='Fixed']">
                <xsl:with-param name="strClass">borderLeftRight</xsl:with-param>
              </xsl:apply-templates>
              <xsl:choose>
                <xsl:when test="count(MeetingWorkBook/Meeting) = 4">
                  <xsl:apply-templates select="$Weekend-Assignments4[@Index='7' and @IndexType='Fixed']">
                    <xsl:with-param name="strClass">borderLeft</xsl:with-param>
                  </xsl:apply-templates>
                </xsl:when>
                <xsl:otherwise>
                  <xsl:apply-templates select="$Weekend-Assignments4[@Index='7' and @IndexType='Fixed']">
                    <xsl:with-param name="strClass">borderLeftRight</xsl:with-param>
                  </xsl:apply-templates>
                  <xsl:apply-templates select="$Weekend-Assignments5[@Index='7' and @IndexType='Fixed']">
                    <xsl:with-param name="strClass">borderLeft</xsl:with-param>
                  </xsl:apply-templates>
                </xsl:otherwise>
              </xsl:choose>
            </tr>
            <!--Cleaning-->
            <xsl:call-template name="BottomRowGap"/>
            <tr>
              <td class="cellLabel">Cleaning</td>
              <xsl:apply-templates select="$Weekend-Assignments1[@Index='0' and @IndexType='Custom']">
                <xsl:with-param name="strClass">cellBold borderRight</xsl:with-param>
                <xsl:with-param name="strExtraText">field service group</xsl:with-param>
              </xsl:apply-templates>
              <xsl:apply-templates select="$Weekend-Assignments2[@Index='0' and @IndexType='Custom']">
                <xsl:with-param name="strClass">cellBold borderLeftRight</xsl:with-param>
                <xsl:with-param name="strExtraText">field service group</xsl:with-param>
              </xsl:apply-templates>
              <xsl:apply-templates select="$Weekend-Assignments3[@Index='0' and @IndexType='Custom']">
                <xsl:with-param name="strClass">cellBold borderLeftRight</xsl:with-param>
                <xsl:with-param name="strExtraText">field service group</xsl:with-param>
              </xsl:apply-templates>
              <xsl:choose>
                <xsl:when test="count(MeetingWorkBook/Meeting) = 4">
                  <xsl:apply-templates select="$Weekend-Assignments4[@Index='0' and @IndexType='Custom']">
                    <xsl:with-param name="strClass">cellBold borderLeft</xsl:with-param>
                    <xsl:with-param name="strExtraText">field service group</xsl:with-param>
                  </xsl:apply-templates>
                </xsl:when>
                <xsl:otherwise>
                  <xsl:apply-templates select="$Weekend-Assignments4[@Index='0' and @IndexType='Custom']">
                    <xsl:with-param name="strClass">cellBold borderLeftRight</xsl:with-param>
                    <xsl:with-param name="strExtraText">field service group</xsl:with-param>
                  </xsl:apply-templates>
                  <xsl:apply-templates select="$Weekend-Assignments5[@Index='0' and @IndexType='Custom']">
                    <xsl:with-param name="strClass">cellBold borderLeft</xsl:with-param>
                    <xsl:with-param name="strExtraText">field service group</xsl:with-param>
                  </xsl:apply-templates>
                </xsl:otherwise>
              </xsl:choose>
            </tr>

          </table>
        </div>
      </body>
    </html>
  </xsl:template>

  <!--Set column widths-->
  <xsl:template name="SetColumnWidths">
    <xsl:choose>
      <xsl:when test="count(MeetingWorkBook/Meeting) = 5">
        <colgroup>
          <col style="width:7%"/>
          <col style="width:17%"/>
          <col style="width:17%"/>
          <col style="width:17%"/>
          <col style="width:17%"/>
          <col style="width:17%"/>
        </colgroup>
      </xsl:when>
      <xsl:otherwise>
        <colgroup>
          <col style="width:10%"/>
          <col style="width:22%"/>
          <col style="width:22%"/>
          <col style="width:22%"/>
          <col style="width:22%"/>
        </colgroup>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <!--Insert a 5 mm merged row-->
  <xsl:template name="BottomRowGap">
    <tr class="rowGap">
      <td colspan="5">
        <xsl:if test="count(MeetingWorkBook/Meeting) = 5">
          <xsl:attribute name="colspan">6</xsl:attribute>
        </xsl:if>
        <div class="rowGapContainer">
          <xsl:text> </xsl:text>
        </div>
      </td>
    </tr>
  </xsl:template>

  <!--Insert a 3 mm merged row-->
  <xsl:template name="TopRowGap">
    <tr class="rowGap">
      <td colspan="5">
        <xsl:if test="count(MeetingWorkBook/Meeting) = 5">
          <xsl:attribute name="colspan">6</xsl:attribute>
        </xsl:if>
        <div class="rowGapContainerSmall">
          <xsl:text> </xsl:text>
        </div>
      </td>
    </tr>
  </xsl:template>

  <!--Inserts the date-->
  <xsl:template match="Date | MeetingDate">
    <td class="cellDate">
      <xsl:value-of select="@MonthFull" />
      <xsl:text> </xsl:text>
      <xsl:value-of  select="@Day" />
      <xsl:choose>
        <xsl:when test="$LangCode='ja' or $LangCode='zh-Hans'">
          <xsl:text>日</xsl:text>
        </xsl:when>
        <xsl:otherwise>
          <xsl:text>.</xsl:text>
        </xsl:otherwise>
      </xsl:choose>
    </td>
  </xsl:template>

  <!--Inserts a empty label cell-->
  <xsl:template name="EmptyLabelCell">
    <td class="cellLabel">
      <xsl:text> </xsl:text>
    </td>
  </xsl:template>

  <!--Inserts the specified heading using the stated CSS class-->
  <xsl:template name="Heading">
    <xsl:param name="strTitle"/>
    <xsl:param name="strClass"/>
    <xsl:call-template name="BottomRowGap"/>
    <tr>
      <xsl:call-template name="EmptyLabelCell"/>
      <td colspan="4" class="{$strClass}">
        <xsl:if test="count(MeetingWorkBook/Meeting) = 5">
          <xsl:attribute name="colspan">5</xsl:attribute>
        </xsl:if>
        <xsl:value-of select="$strTitle"/>
      </td>
    </tr>
    <xsl:call-template name="TopRowGap"/>
  </xsl:template>

  <!--This is used to insert the Chairman, or Special Event-->
  <xsl:template match="Chairman | Event" mode="FirstRow_Pray">
    <xsl:param name="strClass"/>
    <td class="{$strClass}">
      <xsl:if test="self::Event">
        <xsl:attribute name="rowspan">2</xsl:attribute>
      </xsl:if>
      <xsl:value-of select="."/>
    </td>
  </xsl:template>

  <!--This is used to insert the Opening Prayer or Ending Prayer-->
  <xsl:template match="PrayerOpen | PrayerEnd | Assignment" mode="OtherRow">
    <xsl:param name="strClass"/>
    <td class="{$strClass}">
      <xsl:value-of select="."/>
    </td>
  </xsl:template>

  <!--Inserts Chairman or Special Event text with a left border-->
  <xsl:template match="Chairman | Event" mode="Left">
    <td class="cellBold borderLeft">
      <xsl:value-of select="."/>
    </td>
  </xsl:template>

  <!--Inserts Chairman or Special Event text with both left and right borders-->
  <xsl:template match="Chairman | Event" mode="LeftRight">
    <td class="cellBold borderLeftRight">
      <xsl:value-of select="."/>
    </td>
  </xsl:template>

  <!--Inserts Chairman or Special Event text with a right border-->
  <xsl:template match="Chairman | Event" mode="Right">
    <td class="cellBold borderRight">
      <xsl:value-of select="."/>
    </td>
  </xsl:template>

  <!--This is used to insert the Treasures 1 or Special Event-->
  <xsl:template match="Name | Event" mode="FirstRow">
    <xsl:param name="strClass"/>
    <td class="{$strClass}">
      <xsl:if test="self::Event">
        <xsl:attribute name="rowspan">3</xsl:attribute>
      </xsl:if>
      <xsl:value-of select="."/>
    </td>
  </xsl:template>

  <!--This is used to insert the Student or Special Event-->
  <xsl:template match="Event | Student" mode="FirstRow">
    <xsl:param name="strClass"/>
    <td class="{$strClass}">
      <xsl:if test="self::Event">
        <xsl:attribute name="rowspan">4</xsl:attribute>
      </xsl:if>
      <xsl:value-of select="."/>
      <xsl:if test="self::Student">
        <xsl:apply-templates select="../Assistant"/>
      </xsl:if>
    </td>
  </xsl:template>

  <!--This is used to insert the Treasures 2, Bible Reader or Student-->
  <xsl:template match="Name | Reader | Student" mode="OtherRow">
    <xsl:param name="strClass"/>
    <td class="{$strClass}">
      <xsl:value-of select="."/>
      <xsl:if test="self::Student">
        <xsl:apply-templates select="../Assistant"/>
      </xsl:if>
    </td>
  </xsl:template>

  <!--This is used to insert the Assistant-->
  <xsl:template match="Assistant">
    <br/>
    <span class="textStudentAssistant">
      <xsl:value-of select="."/>
    </span>
  </xsl:template>

  <!--This is used whenever the student item is a conversation video
  Technically we only support the main hall, so the counsellor label should never be used-->
  <xsl:template match="Students[@ChairmanHandleSampleVideo and @Class='1']">
    <xsl:param name="strClass"/>
    <td class="{$strClass}">
      <xsl:choose>
        <xsl:when test="@ChairmanHandleSampleVideo=0">
          <xsl:value-of select="//Labels/Counsellor"/>
        </xsl:when>
        <xsl:otherwise>
          <!--Trims the " :" from the end of the chairman label-->
          <xsl:value-of select="normalize-space(translate(//Labels/Chairman,':',''))"/>
        </xsl:otherwise>
      </xsl:choose>
    </td>
  </xsl:template>

  <!--This is used to insert the LAC Item Theme or Special Event-->
  <xsl:template match="Event | Theme">
    <xsl:param name="strClass"/>
    <td class="{$strClass}">
      <xsl:if test="self::Event">
        <xsl:choose>
          <xsl:when test="count(//MeetingWorkBook/Meeting[1]/LAC/LACItem) = 2 or 
                  count(//MeetingWorkBook/Meeting[2]/LAC/LACItem) = 2 or 
                  count(//MeetingWorkBook/Meeting[3]/LAC/LACItem) = 2 or 
                  count(//MeetingWorkBook/Meeting[4]/LAC/LACItem) = 2 or 
                  count(//MeetingWorkBook/Meeting[5]/LAC/LACItem) = 2">
            <xsl:attribute name="rowspan">4</xsl:attribute>
          </xsl:when>
          <xsl:otherwise>
            <xsl:attribute name="rowspan">2</xsl:attribute>
          </xsl:otherwise>
        </xsl:choose>
        <xsl:attribute name="class">
          cellBold <xsl:value-of select="$strClass"/>
        </xsl:attribute>
      </xsl:if>
      <xsl:value-of select="."/>
    </td>
  </xsl:template>

  <!--This is used to insert the Public Talk Speaker and Theme, Chairman or Special Event-->
  <xsl:template match="Chairman | Event | Speaker | Theme" mode="Weekend">
    <xsl:param name="strClass"/>
    <td>
      <xsl:choose>
        <xsl:when test="self::Event">
          <xsl:attribute name="rowspan">3</xsl:attribute>
          <xsl:attribute name="class">
            cellBold <xsl:value-of select="$strClass"/>
          </xsl:attribute>
        </xsl:when>
        <xsl:when test="self::Theme">
          <xsl:choose>
            <xsl:when test="../../../LAC/@CircuitVisit='1'">
              <xsl:attribute name="class">
                cellCircuitVisit <xsl:value-of select="$strClass"/>
              </xsl:attribute>
            </xsl:when>
            <xsl:otherwise>
              <xsl:attribute name="class">
                <xsl:value-of select="$strClass"/>
              </xsl:attribute>
            </xsl:otherwise>
          </xsl:choose>
        </xsl:when>
        <xsl:when test="self::Speaker">
          <xsl:choose>
            <xsl:when test="../../../LAC/@CircuitVisit='1'">
              <xsl:attribute name="class">
                cellCircuitVisit cellBold <xsl:value-of select="$strClass"/>
              </xsl:attribute>
            </xsl:when>
            <xsl:otherwise>
              <xsl:attribute name="class">
                cellBold <xsl:value-of select="$strClass"/>
              </xsl:attribute>
            </xsl:otherwise>
          </xsl:choose>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="class">
            cellBold <xsl:value-of select="$strClass"/>
          </xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>
      <xsl:value-of select="."/>
    </td>
  </xsl:template>

  <xsl:template match="Conductor | Event | Reader | ServiceTalk | Theme | Hospitality" mode="WatchtowerStudy">
    <xsl:param name="strClass"/>
    <td class="{$strClass}">
      <xsl:choose>
        <xsl:when test="self::Event">
          <xsl:attribute name="rowspan">4</xsl:attribute>
          <xsl:value-of select="."/>
        </xsl:when>
        <xsl:when test="self::ServiceTalk">
          <xsl:value-of select="$Translations/msa:Translations/msa:*[local-name() = $LangCode]/msa:ServiceTalk"/>
          <br/>
          <span style="font-weight: normal;">
            <xsl:value-of select="./Theme" />
          </span>
        </xsl:when>
        <xsl:otherwise>
          <xsl:value-of select="."/>
        </xsl:otherwise>
      </xsl:choose>
    </td>
  </xsl:template>

  <!--This is used to insert the LAC Item Time and Name-->
  <xsl:template match="LACItem">
    <xsl:param name="strClass"/>
    <td class="{$strClass}">
      <br style="line-height:1mm"/>
      <table width="100%" style="padding: 0; margin: 0; border-style: none;">
        <colgroup>
          <col width=" 25mm;" style="background-color:#eaeaea;"/>
        </colgroup>
        <td style="border: 0px #d3d3d3 solid;">
          <xsl:value-of select="Time"/>
        </td>
        <td style="border-style: none;" class="cellBold">
          <xsl:value-of select="Name"/>
        </td>
      </table>
    </td>
  </xsl:template>

  <!--This is used to insert the CBS Conductor, CBS Reader, Special Event (for CBS rows) or Circuit Visit Talk (for CBS rows)-->
  <xsl:template match="Conductor | Event | Reader | CircuitVisit" mode ="CBS">
    <xsl:param name="strClass"/>
    <td class="cellBold {$strClass}">
      <xsl:choose>
        <xsl:when test="self::Event">
          <xsl:attribute name="rowspan">4</xsl:attribute>
          <xsl:value-of select="."/>
        </xsl:when>
        <xsl:when test="self::CircuitVisit">
          <xsl:attribute name="rowspan">2</xsl:attribute>
          <xsl:value-of select="$Translations/msa:Translations/msa:*[local-name() = $LangCode]/msa:ServiceTalk"/>
          <br/>
          <span style="font-weight: normal;">
            <xsl:value-of select="LACItem/Theme"/>
          </span>
        </xsl:when>
        <xsl:otherwise>
          <xsl:value-of select="."/>
        </xsl:otherwise>
      </xsl:choose>
    </td>
  </xsl:template>

  <xsl:template match="msa:Assignment">
    <xsl:param name="strClass"/>
    <xsl:param name="strExtraText"/>
    <td class="{$strClass}">
      <xsl:value-of select="."/>
      <xsl:if test="$strExtraText != ''">
        <span style="font-weight: normal; font-size: 8pt;">
          <br/>
          <xsl:value-of select="$strExtraText"/>
        </span>
      </xsl:if>
    </td>
  </xsl:template>

  <!--This is used to insert the Special Event in Assignments-->
  <xsl:template match="Event" mode="Assignment">
    <xsl:param name="strClass"/>
    <td class="{$strClass}">
      <xsl:if test="self::Event">
        <xsl:attribute name="rowspan">6</xsl:attribute>
        <xsl:attribute name="class">
          cellBold <xsl:value-of select="$strClass"/>
        </xsl:attribute>
      </xsl:if>
      <xsl:value-of select="."/>
    </td>
  </xsl:template>
</xsl:stylesheet>